<?php

namespace App\Http\Controllers;

use DB;
use Auth;
use Mail;
use File;
use DataTables;
use App\Models\User;
use App\Models\Tutor;
use App\Models\TuitionCentre;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Mail\AdminNotificationForTutorCreation;
use App\Models\Account;
use App\Mail\TutorMail;
use App\Mail\TuitionCenter;
use App\Models\ClickedPage;

class AccountController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-admin')->only('index', 'dataAdmin');
        $this->middleware('permission:create-admin')->only('createAdmin', 'storeAdmin');
        $this->middleware('permission:edit-admin')->only('editAdmin', 'updateAdmin');
        $this->middleware('permission:delete-admin')->only('destroyAdmin');
        $this->middleware('permission:show-details-admin')->only('show');

        // $this->middleware('permission:create-parent')->only('createParentAccountIndex');

        // $this->middleware('permission:create-tutor')->only('createTutorAccountIndex', 'storeTutorAccount');
        // $this->middleware('permission:edit-tutor')->only('updateTutorAccountIndex', 'updateTutorAccount');
    }
    public function dataAdmin()
    {
        $all_users = User::orderBy('updated_at','desc')->get();
        $admins = [];
        foreach($all_users as $user){
            $role = DB::table('model_has_roles')->where('model_id',$user->id)->first();
            if($role != ''){
                if($user->roles->first()->name == 'super_admin' || $user->roles->first()->name == 'admin'){
                    array_push($admins, $user);
                }
            }

        }

        return DataTables::of($admins)
        ->editColumn('role', function ($admin) {
            $role = $admin->roles->first();
            if($role)
                return ucfirst(str_replace('_',' ',$role->name));
            else
                return '-';
        })
        ->editColumn('created_at', function ($admin) {
            return date('d-m-Y', strtotime($admin->created_at));
        })
        ->editColumn('contact_number', function ($admin) {
            $account = Account::where('user_id',$admin->id)->first();
            return $account->contact_number;
        })
        ->addColumn('updated_at', function ($admin) {
            return date('Y-m-d', strtotime($admin->updated_at));
        })
        ->editColumn('email', function ($admin) {
            return $admin->email;
        })
        ->editColumn('status', function ($admin) {
            $account = Account::where('user_id',$admin->id)->first();
            if($account->status == 'inactive'){
                return '<a class="btn btn-warning" onclick="return confirm(\'Are you sure want to Active ?\');" style="border:none;color:#ce7906;background:#ed921847;" href="'.route('account.changestatus',['id' => $admin->id,'value' => 1,'user'=>'Admin']).'">Inactive</a>';
            }else{
                return '<a class="btn btn-success" onclick="return confirm(\'Are you sure want to Inactive ?\');" style="border:none;color:#26ab38;background:#26ab3863;" href="'.route('account.changestatus',['id' => $admin->id,'value' => 0,'user'=>'Admin']).'">Active</a>';
            }
        })
        ->addColumn('actions', function ($admin) {
            return view('admins.action', ['admin' => $admin]);
        })
        ->escapeColumns('ratings')
        ->rawColumns(['actions','status'])->make(true);
    }

    public function create(Request $request)
    {
        if($request->tuition_center == 'on'){
            return redirect()->route('tuition-centre.create');
        } elseif($request->tutor == 'on') {
            return redirect()->route('tutor.create');
        } else {
            $edit = 0;
            return view('admins.create',compact('edit'));
        }
    }

    public function ChangeStatus(Request $request){
        $store = Account::where('user_id',$request->id)->first();
        $store->status = $request->value == '0' ? 'inactive' : 'active';
        $store->save();
        $status = $request->value == 0 ? 'Inactived' : 'Activated';
        return redirect()->back()->with('message',$request->user.' '.$status.' Successfully.');
    }

    public function index(){
        return view('admins.index');
    }

    public function createAdmin()
    {
        $roles = Role::all();
        $edit = 0;
        $role = '';
        $contact_number = 65;
        return view('admins.create', compact('roles','edit','role','contact_number'));
    }

    public function show(Request $request,$id)
    {
        if($request->show){
            $show = $request->show;
          }else{
            $show = '';
          }
        $value = Account::where('user_id',$id)->first();
        $user = User::find($id);
        $role = $user->roles->first()->name;
        $previous = route('admin.index');
        $edit_route = route('admin.edit', $id);
        return view('admins.show',compact('value','role','show','previous','edit_route'));
    }

    public function storeAdmin(Request $request)
    {
        // dd($request->all());
        $this->validate($request, [
            // 'profile_picture' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'gender' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email',
            'contact_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:6',
        ]);

        $user = User::create([
            'name' => $request->first_name." ".$request->last_name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);
        // $user->assignRole($request->role_id);
        $user->assignRole('admin');

        $updated_logo_name = "";
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

            $updated_logo_name = $imageName;
        }
        if($request->status){
            $status = $request->status;
        }else{
            $status = 'active';
        }
        $superadmin_details = array(
            'user_id' => $user->id,
            'profile_picture' => $updated_logo_name,
            'first_name' => $request->first_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'street_name' => $request->street_name,
            'state' => $request->state,
            'city' => $request->city,
            'zip_code' => $request->zip_code,
            'email' => $request->email,
            'contact_number' => $request->countryCode.$request->contact_number,
            'remarks' => $request->remarks,
            'status' => $status
        );
        DB::table('accounts')->insert($superadmin_details);
        return redirect()->route('admin.index')->with('message', 'Admin created successfully');

    }

    public function editAdmin(Request $request,$id)
    {
        $admin = User::find($id);
        $admin_details = DB::table('accounts')->where('user_id',$id)->first();
        $roles = Role::all();
        $edit = 1;
        if($request->from_profile){
            $previous = route('admin.show',$id);
            $from_profile = 1;
        }else{
            $previous = route('admin.index');
            $from_profile = 0;
        }
        $role = $admin->roles->first()->name;
        $contact_number = substr($admin_details->contact_number, 0, -10) == '' ? 65 : substr($admin_details->contact_number, 0, -10);
        return view('admins.edit', compact('roles', 'admin','admin_details','edit','previous','from_profile','role','contact_number'));
    }

    public function updateAdmin(Request $request,$id)
    {
        // dd($request,$id);
        $sup = DB::table('accounts')->where('user_id',$id)->first();
        $sup_id = $sup ? $sup->id : '';
        $this->validate($request, [
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'gender' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email,'.$id,
            'contact_number' => 'required',
        ]);

        $user = User::find($id);
        // $user->syncRoles($request->role_id);
        if($request->status){
            $status = $request->status;
        }else{
            $status = 'active';
        }
        $updated_logo_name = "";
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

            $updated_logo_name = $imageName;
        }

        if($request->password != ""){
            if($request->password != $request->password_confirmation){
                return redirect()->back()->withErrors(["Confirm Password didn't match"])->withInput();
            } else {
                $user = User::where('id', $id)->update([
                    'name' => $request->first_name." ".$request->last_name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password)
                ]);
            }
        } else {
            $user = User::where('id', $id)->update([
                'name' => $request->first_name." ".$request->last_name,
                    'email' => $request->email,
            ]);
        }
        $find_admin = DB::table('accounts')->where('user_id',$id)->first();
        if($find_admin != ''){
        if($updated_logo_name){
            $superadmin_details = array(
                'profile_picture' => $updated_logo_name,
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'gender' => $request->gender,
                'street_name' => $request->street_name,
                'state' => $request->state,
                'city' => $request->city,
                'zip_code' => $request->zip_code,
                'email' => $request->email,
                'contact_number' => $request->countryCode.$request->contact_number,
                'remarks' => $request->remarks,
                'status' => $status
            );
        } else {
            $superadmin_details = array(
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'gender' => $request->gender,
                'street_name' => $request->street_name,
                'state' => $request->state,
                'city' => $request->city,
                'zip_code' => $request->zip_code,
                'email' => $request->email,
                'contact_number' => $request->countryCode.$request->contact_number,
                'remarks' => $request->remarks,
                'status' => $status
            );
        }
        DB::table('accounts')->where('user_id',$id)->update($superadmin_details);

    }else{
        $superadmin_details = array(
            'user_id' => $id,
            'profile_picture' => $updated_logo_name,
            'first_name' => $request->first_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'street_name' => $request->street_name,
            'state' => $request->state,
            'city' => $request->city,
            'zip_code' => $request->zip_code,
            'email' => $request->email,
            'contact_number' => $request->countryCode.$request->contact_number,
            'remarks' => $request->remarks,
            'status' => $status
        );
        DB::table('accounts')->insert($superadmin_details);
    }
    if($request->from_profile == 1){
        return redirect()->route('admin.show',$id)->with('message', 'Admin updated successfully');
    }else{
        return redirect()->route('admin.index')->with('message', 'Admin updated successfully');
    }
    }

    public function destroyAdmin(Request $request, $id)
    {
        User::find($id)->delete();
        DB::table('accounts')->where('user_id',$id)->delete();

        return redirect()->route('admin.index')->with('message', 'Admin deleted successfully');
    }

    public function subscriptionIndex()
    {
        return view('admins.subscription');
    }

    public function subscriptionData()
    {
        // $user = Auth::user();
        // $centre = TuitionCentre::where('user_id', $user->id)->first();
        // $tutors = [];
        // if($centre)
        //     $tutors = Tutor::where('tuition_centre_id', $centre->id)->get();
        $user = User::role('tutor')->pluck('id')->toArray();
        $tutors = Account::whereIn('user_id', $user)->get();

        return DataTables::of($tutors)
            ->editColumn('name', function ($tutor) {
                return $tutor->first_name." ".$tutor->last_name;
            })
            ->editColumn('invoice_date', function ($tutor) {
                return "-";
            })
            ->editColumn('invoice_number', function ($tutor) {
                return "-";
            })
            ->editColumn('fee_str', function ($tutor) {
                return "-";
            })
            ->editColumn('payment_recieved', function ($tutor) {
                return "-";
            })
            ->editColumn('total_amt', function ($tutor) {
                return "-";
            })
            ->rawColumns(['actions'])->make(true);
    }

    public function cancel($tab)
    {
        return redirect()->route('home')->with('tab', $tab);
    }

    public function createTutorAccountIndex(Request $request)
    {
        if($request->show){
            $show = 1;
        }else{
            $show = 0;
        }
        $contact_number = 65;
        $users = Auth::user();
        if($users == ''){
            return view('accounts.create_tutor_account',compact('show','contact_number'));
        }else{
            return redirect()->route('home');
        }
    }


    public function createParentAccountIndex(Request $request){
        // dd($request->all());
        if($request->provider_id){
            $m = date("n",strtotime(date('M')));
            $store = ClickedPage::where('user_role',$request->provider_type)->where('provider_id',$request->provider_id)->whereYear('created_at',date('Y'))->whereMonth('created_at', $m)->first();
            if($store == ''){
                $store = new ClickedPage();
                $store->clicked_count = 1;
            }else{
                $store->clicked_count = $store->clicked_count + 1;
            }
            $store->user_role = $request->provider_type;
            $store->provider_id = $request->provider_id;
            $store->save();
        }
        session()->forget('my_test_key');
        if($request->show){
            $show = 1;
        }else{
            $show = 0;
        }
        $edit = 0;
        $class_id = $request->class_id;
        $users = Auth::user();
        if($users == ''){
            return view('parents.signup',compact('show','edit','class_id'));
        }else{
            return redirect()->route('home');
        }
    }

    public function storeTutorAccount(Request $request)
    {
        // dd($request->all());
        $users = Auth::user();
        if($users != ''){
            return redirect()->route('home');
        }
        $this->validate($request, [
            // 'profile_picture' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'email' => 'required|email|unique:accounts,email',
            'contact_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:8',
        ]);

        $user = User::create([
            'name' => $request->first_name . " " . $request->last_name,
            'email' => $request['email'],
            'password' => Hash::make($request['password']),
        ]);

        $user->assignRole('tutor');
        $tutor = new Account();

        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

             $tutor->profile_picture = $imageName;
        }

        if ($request->upload_document != '') {
                $image = $request->upload_document_url;  // your base64 encoded
                $image = str_replace('data:image/png;base64,', '', $image);
                $image = str_replace(' ', '+', $image);
                $imageName = $request->upload_document;

                $path = public_path() . '/upload_documents/';
                File::exists($path) or File::makeDirectory($path, 0777, true);
                File::put(public_path() . '/upload_documents/' . $imageName, base64_decode($image));

                 $tutor->upload_document = $imageName;
        }
        // if ($logo = $request->file('profile_picture')) {
        //     $logo_name = $request->first_name . $request->file('profile_picture')->getClientOriginalName();
        //     $target_path = public_path('/profile_pictures/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $tutor->profile_picture = $logo_name;
        //     }
        // }
        // if ($logo = $request->file('upload_document')) {
        //     $logo_name = $request->first_name . $request->file('upload_document')->getClientOriginalName();
        //     $target_path = public_path('/upload_documents/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $tutor->upload_document = $logo_name;
        //     }
        // }

        $tutor->user_id = $user->id;
        $tutor->first_name = $request->first_name;
        $tutor->last_name = $request->last_name;
        $tutor->email = $request->email;
        $tutor->tutor_type_id = $request->tutor_type_id; // 1- fulltime | 2 - parttime
        $tutor->breif_note = $request->breif_note;
        $tutor->contact_number = $request->countryCode.$request->contact_number;
        $tutor->remarks = $request->remarks;
        $tutor->password = Hash::make($request->password);
        $tutor->created_by = $user->id;
        $tutor->street_name = $request->street_name;
        $tutor->state = $request->state;
        $tutor->city = $request->city;
        $tutor->zip_code = $request->zip_code;
        $tutor->work_experience = $request->work_experience;
        $tutor->save();
        if ($request->subjects) {
            foreach ($request->subjects as $sub) {
                $data = array(
                    'tutor_id' => $tutor->id,
                    'subject_id' => $sub,
                    'created_at' => date('Y-m-d'),
                );
                DB::table('tutor_subjects')->insert($data);
            }
        }

        if($request->special_class_days){
            foreach ($request->special_class_days as $key => $value) {
                if ($value['institute_name1'] != null && $value['course_name1'] != null) {
                    $data = array(
                        'tutor_id' => $tutor->id,
                        'institute_name' => $value['institute_name1'],
                        'course_name' => $value['course_name1'],
                        'start_date' => $value['start_date_e'] != null  ? date('Y-m-d',strtotime($value['start_date_e'])) : null,
                        'end_date' => $value['end_date_e'] != null  ? date('Y-m-d',strtotime($value['end_date_e'])) : null,
                        'created_at' => date('Y-m-d'),
                    );
                    DB::table('tutor_educations')->insert($data);
                }
            }
        }

        if($request->working_expepierances){
            foreach ($request->working_expepierances as $key => $value) {
                if ($value['institute_name'] != null && $value['job_title'] != null && $value['start_date'] != null && $value['end_date'] != null) {
                    $data = array(
                        'tutor_id' => $tutor->id,
                        'institute_name' => $value['institute_name'],
                        'job_location' => $value['job_location'],
                        'job_type' => $value['job_type'],
                        'job_title' => $value['job_title'],
                        'start_date' => $value['start_date'] != null  ? date('Y-m-d',strtotime($value['start_date'])) : null,
                        'end_date' => $value['end_date'] != null  ? date('Y-m-d',strtotime($value['end_date'])) : null,
                    );
                    DB::table('tutor_exps')->insert($data);
                }
            }
        }


        $admin = DB::table('users')
                ->select('users.email')
                ->leftJoin('model_has_roles','users.id','=','model_has_roles.model_id')
                ->leftJoin('roles','roles.id','=','model_has_roles.role_id')
                ->where('roles.id',6)
                ->first();

        $users = Auth::user();


        if($users == ''){
            Mail::to($admin->email)->send(new AdminNotificationForTutorCreation($tutor));
            Auth::loginUsingId($user->id);
            return redirect()->route('home')->with('message','You Have Registered Successfully');
        }else{
            if ($users->roles->first()->name == 'tuition center') {
                return redirect()->route('centre-manager.index')->with('message', 'Tutor data saved successfully');
            }elseif($users->roles->first()->name == 'tutor'){
                return redirect()->route('home')->with('message','Profile Updated Successfully');
            }
        }

        if ($users != '') {
            $title = "Tutor";
            $msg = $request->first_name.' tutor created';

            Mail::to($request->email)->send(new TutorMail($title, $msg));
        }
        return redirect()->route('tutor.index')->with('message', 'Tutor data saved successfully');
    }

    public function updateTutorAccountIndex(Request $request){
        $tutor = Account::find($request->id);
        $subjects = DB::table('tutor_subjects')->where('tutor_id', $tutor->id)->pluck('subject_id')->toArray();
        $tutor_educations = DB::table('tutor_educations')->where('tutor_id',$tutor->id)->first();
        $tutor_educations_detail = DB::table('tutor_educations')->where('tutor_id',$tutor->id)->get();
        $tutor_exp = DB::table('tutor_exps')->where('tutor_id',$tutor->id)->first();
        $tutor_work_exp = DB::table('tutor_exps')->where('tutor_id',$tutor->id)->get();
        $show = 0;
        if($request->from_profile){
            $previous = route('tutor.show',$tutor->user_id);
            $from_profile = 1;
        }else{
            $previous = route('tutor.index');
            $from_profile = 0;
        }
        $contact_number = substr($tutor->contact_number, 0, -10) == '' ? 65 : substr($tutor->contact_number, 0, -10);
        return view('accounts.edit_tutor_account',compact('contact_number','tutor','subjects','previous','tutor_educations','tutor_exp','show','from_profile','tutor_educations_detail','tutor_work_exp'));
    }

    public function updateTutorAccount(Request $request,$id)
    {
        // dd($request->all());
        $this->validate($request, [
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'email' => 'required|email|unique:accounts,email,' . $id,
            'contact_number' => 'required',
        ]);

        $tutor = Account::find($id);
        $user = User::find($tutor->user_id);
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

             $tutor->profile_picture = $imageName;
        }

        if ($request->upload_document != '') {
                $image = $request->upload_document_url;  // your base64 encoded
                $image = str_replace('data:image/png;base64,', '', $image);
                $image = str_replace(' ', '+', $image);
                $imageName = $request->upload_document;

                $path = public_path() . '/upload_documents/';
                File::exists($path) or File::makeDirectory($path, 0777, true);
                File::put(public_path() . '/upload_documents/' . $imageName, base64_decode($image));

                 $tutor->upload_document = $imageName;
        }

        $tutor->user_id = $user->id;
        $tutor->first_name = $request->first_name;
        $tutor->last_name = $request->last_name;
        $tutor->email = $request->email;
        $tutor->tutor_type_id = $request->tutor_type_id; // 1- fulltime | 2 - parttime
        $tutor->breif_note = $request->breif_note;
        $tutor->contact_number = $request->countryCode.$request->contact_number;
        $tutor->remarks = $request->remarks;
        $tutor->password = Hash::make($request->password);
        $tutor->created_by = $user->id;
        $tutor->street_name = $request->street_name;
        $tutor->state = $request->state;
        $tutor->city = $request->city;
        $tutor->zip_code = $request->zip_code;
        $tutor->work_experience = $request->work_experience;
        if ($request->password != "") {
            if ($request->password != $request->password_confirmation) {
                return redirect()->back()->withErrors(["Confirm Password didn't match"])->withInput();
            } else {
                User::where('id', $tutor->user_id)->update([
                    'name' => $request->first_name . " " . $request->last_name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password),
                ]);
                $tutor->password = Hash::make($request->password);
            }
        } else {
            $user = User::where('id', $tutor->user_id)->update([
                'name' => $request->first_name . " " . $request->last_name,
                'email' => $request->email,
            ]);
        }
        $tutor->save();

        if ($request->subjects) {
            DB::table('tutor_subjects')->where('tutor_id', $tutor->id)->delete();
            foreach ($request->subjects as $sub) {
                $data = array(
                    'tutor_id' => $tutor->id,
                    'subject_id' => $sub,
                    'created_at' => date('Y-m-d'),
                );
                DB::table('tutor_subjects')->insert($data);
            }
        }
            DB::table('tutor_educations')->where('tutor_id', $tutor->id)->delete();

            foreach ($request->special_class_days as $key => $value) {
                if ($value['institute_name1'] != null && $value['course_name1'] != null) {
                    $data = array(
                        'tutor_id' => $tutor->id,
                        'institute_name' => $value['institute_name1'],
                        'course_name' => $value['course_name1'],
                        'start_date' => $value['start_date_e'] != null  ? date('Y-m-d',strtotime($value['start_date_e'])) : null,
                        'end_date' => $value['end_date_e'] != null  ? date('Y-m-d',strtotime($value['end_date_e'])) : null,
                        'created_at' => date('Y-m-d'),
                    );
                    DB::table('tutor_educations')->insert($data);
                }
            }

            DB::table('tutor_exps')->where('tutor_id', $tutor->id)->delete();
            foreach ($request->working_expepierances as $key => $value) {
                if ($value['institute_name'] != null && $value['job_title'] != null && $value['start_date'] != null && $value['end_date'] != null) {
                    $data = array(
                        'tutor_id' => $tutor->id,
                        'institute_name' => $value['institute_name'],
                        'job_location' => $value['job_location'],
                        'job_type' => $value['job_type'],
                        'job_title' => $value['job_title'],
                        'start_date' => $value['start_date'] != null  ? date('Y-m-d',strtotime($value['start_date'])) : null,
                        'end_date' => $value['end_date'] != null  ? date('Y-m-d',strtotime($value['end_date'])) : null,
                    );
                    DB::table('tutor_exps')->insert($data);
                }
            }


        $admin = DB::table('users')
                ->select('users.email')
                ->leftJoin('model_has_roles','users.id','=','model_has_roles.model_id')
                ->leftJoin('roles','roles.id','=','model_has_roles.role_id')
                ->where('roles.id',6)
                ->first();

        Mail::to($admin->email)->send(new AdminNotificationForTutorCreation($tutor));
        $user = Auth::user();
        if($request->from_profile == 1){
            return redirect()->route('tutor.show',$tutor->user_id)->with('message', 'Tutor data saved successfully');
        }else{
        if ($user->roles->first()->name == 'tuition center') {
            return redirect()->route('centre-manager.index')->with('message', 'Tutor data saved successfully');
        }elseif($user->roles->first()->name == 'tutor'){
            return redirect()->route('home')->with('message','Profile Updated Successfully');
        }
        return redirect()->route('tutor.index')->with('message', 'Tutor data saved successfully');
        }
    }

    public function createTuitionCenterAccountIndex()
    {
        $users = Auth::user();
        $contact_number = 65;
        $cp_contact_number = 65;
        if($users == ''){
            return view('accounts.create_tuition_center_account',compact('contact_number','cp_contact_number'));
        }else{
            return redirect()->route('home');
        }
    }

    public function storeTuitionCenterAccount(Request $request)
    {
        $users = Auth::user();
        if($users != ''){
            return redirect()->route('home');
        }
        $this->validate($request, [
            // 'logo_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'name' => 'required|min:3|max:50|unique:tuition_centres,name,NULL,id',
            'uen' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email,NULL,id',
            'contact_number' => 'required',
            'contact_person_name' => 'required',
            'contact_person_email' => 'required',
            'contact_person_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:6',
        ]);

        $centre = new TuitionCentre();
        if ($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/logo_images/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/logo_images/' . $imageName, base64_decode($image));

            $centre->logo_name = $imageName;
            }

        $this_user = User::create([
            'name' => $request->contact_person_name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);

        $this_user->assignRole('tuition center');

        $centre->user_id = $this_user->id;
        $centre->name = $request->name;
        $centre->uen = $request->uen;
        $centre->street_name = $request->street_name;
        $centre->state = $request->state;
        $centre->city = $request->city;
        $centre->zip_code = $request->zip_code;
        $centre->email = $request->email;
        $centre->contact_number = $request->countryCode.$request->contact_number;
        $centre->website = $request->website;
        $centre->contact_person_name = $request->contact_person_name;
        $centre->contact_person_email = $request->contact_person_email;
        $centre->contact_person_number = $request->countryCode1.$request->contact_person_number;
        $centre->remarks = $request->remarks;
        $centre->description = $request->description;
        $centre->created_by = $this_user->id;
        $centre->save();
        $admin = DB::table('users')
                ->select('users.email')
                ->leftJoin('model_has_roles','users.id','=','model_has_roles.model_id')
                ->leftJoin('roles','roles.id','=','model_has_roles.role_id')
                ->where('roles.id',6)
                ->first();

        $title = "Create new tuition center";
        $msg = $request->name.' tuition center created';

        Mail::to($admin->email)->send(new TuitionCenter($title, $msg));
        Auth::loginUsingId($this_user->id);
        return redirect()->route('home')->with('message','Tuition Centre Registered Successfully');
    }

    public function loginTutor()
    {
        return view('accounts.login_tutor');
    }

    public function loginTuitionCenter()
    {
        return view('accounts.login_tuition_center');
    }

    public function validate_email(Request $request)
    {
        if($request->name){
            if($request->from == 'centre'){
                 if($request->id){
                    $find_name = TuitionCentre::where('name',$request->name)->where('id','!=',$request->id)->first();
                 }else{
                    $find_name = TuitionCentre::where('name',$request->name)->first();
                 }
            }else{
                $find_name = TuitionCentre::where('name',$request->name)->first();
            }
           if($find_name != ''){
            $return =  false;
           }else{
            $return= true;
           }
        }elseif($request->first_name){
            if($request->from == 'tutor'){
                if($request->id){
                   $find_name = Account::where('first_name',$request->first_name)->where('id','!=',$request->id)->first();
                }else{
                   $find_name = Account::where('first_name',$request->first_name)->first();
                }
           }else{
               $find_name = Account::where('first_name',$request->first_name)->first();
           }
          if($find_name != ''){
           $return =  false;
          }else{
           $return= true;
          }
        }
        elseif($request->email){
           if($request->from == 'centre'){
            if($request->id){
                $centre = TuitionCentre::find($request->id);
                $find_name = User::where('email',$request->email)->where('id','!=',$centre->user_id)->first();
            }else{
                $find_name = User::where('email',$request->email)->first();
            }
           }elseif($request->from == 'parent'){
            if($request->id){
                $find_name = User::where('email',$request->email)->where('id','!=',$request->id)->first();
                }else{
                $find_name = User::where('email',$request->email)->first();
                }
           }else{
            if($request->id){
            $find_name = Account::where('email',$request->email)->where('id','!=',$request->id)->first();
            }else{
            $find_name = Account::where('email',$request->email)->first();
            }
           }
            if($find_name != ''){
             $return =  false;
            }else{
             $return= true;
            }
        }elseif($request->email_edit){
            if($request->id){
                $find_name = Account::where('email',$request->email_edit)->where('id','!=',$request->id)->first();
            }else{
                $find_name = Account::where('email',$request->email_edit)->first();
            }
            if($find_name != ''){
                $return =  false;
               }else{
                $return= true;
            }
        }
        echo json_encode($return);
    }
}
