<?php

namespace App\Http\Controllers;

use App\Models\AdsBanner;
use App\Models\BannerClicked;
use Illuminate\Http\Request;
use DataTables;
use File;
class BannerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-banner')->only('index', 'getData');
        $this->middleware('permission:create-banner')->only('create', 'store');
        $this->middleware('permission:edit-banner')->only('edit', 'update');
        $this->middleware('permission:delete-banner')->only('destroy');
    }
    public function index()
    {
        return view('banner.index');
    }
    public function reorderRows(Request $request)
    {
        // dd($request->all());
        $newOrder = $request->input('order');
        // dd($newOrder);
        foreach ($newOrder as $order => $itemId) {
            AdsBanner::where('id', $itemId)->update(['position' => $order]);
        }

        return response()->json(['message' => 'Rows reordered successfully']);
    }
    public function getData()
    {
        $banner = AdsBanner::orderBy('position','asc')->get();
        return DataTables::of($banner)
        ->addIndexColumn()
        ->editColumn('image', function ($banner) {
            return '<img width="100px" height="100px" style="border:2px solid #c5cdd5;" src="ads_banner/'.$banner->image.'">';
        })
        ->editColumn('status', function ($banner) {
            return ucfirst($banner->status);
        })
        ->editColumn('clicked', function ($banner) {
            $data = BannerClicked::where('banner_id',$banner->id)->first();
            return $data ? $data->clicked : '';
        })
        ->editColumn('created_at', function ($banner) {
            return date('d-m-Y', strtotime($banner->created_at));
        })
        ->addColumn('updated_at', function ($banner) {
            return date('Y-m-d', strtotime($banner->updated_at));
        })
        ->addColumn('actions', function ($banner) {
            return view('banner.action', ['banner' => $banner]);
        })
        ->rawColumns(['actions','image'])->make(true);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('banner.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $store = new AdsBanner();
        if($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/ads_banner/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/ads_banner/' . $imageName, base64_decode($image));

            $store->image = $imageName;
        }
        $store->name = $request->name;
        $store->status = $request->status;
        $store->save();
        return redirect()->route('banner.index')->with('message', 'Banner Created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data = AdsBanner::find($id);
        return view('banner.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // dd($request->all());
        $update = AdsBanner::find($id);
        if($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/ads_banner/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/ads_banner/' . $imageName, base64_decode($image));

            $update->image = $imageName;
        }
        $update->name = $request->name;
        $update->status = $request->status;
        $update->save();
        return redirect()->route('banner.index')->with('message', 'Banner Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $data = AdsBanner::find($id);
        $data->delete();
        $del = BannerClicked::where('banner_id',$id)->delete();
        return redirect()->route('banner.index')->with('message', 'Banner Deleted successfully');
    }
}
