<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DataTables;
use App\Models\Broadcast;
use App\Models\User;
use Spatie\Permission\Models\Role;
use App\Notifications\StudentJoinClass;
use App\Mail\StudentMail;
use App\Models\Account;
use App\Models\TuitionCentre;
use Illuminate\Support\Facades\Mail;

class BroadcastController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-broadcast')->only('index', 'data');
        $this->middleware('permission:create-broadcast')->only('create', 'store');
        $this->middleware('permission:edit-broadcast')->only('edit', 'update');
        $this->middleware('permission:delete-broadcast')->only('destroy');
        $this->middleware('permission:send-broadcast')->only('BroadcastSend');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('broadcast.index');
    }

    public function data(Request $request)
    {
        $broadcasts = Broadcast::all();

        return DataTables::of($broadcasts)
            ->addIndexColumn()
            ->addColumn('user', function ($broadcast) {
                if($broadcast->role_id != ''){
                    $role_ids = explode(',', $broadcast->role_id);
                    $roles = Role::whereIn('id', $role_ids)->get();
                    $role_name = [];
                    foreach ($roles as $key => $value) {
                        $role_name[] = $value->name;
                    }
                    return implode(",", $role_name);
                }else{
                    $role_ids = explode(',', $broadcast->user_id);
                    $roles = User::whereIn('id', $role_ids)->get();
                    $role_name = [];
                    foreach ($roles as $key => $value) {
                        $role_name[] = $value->email;
                    }
                    return implode(",", $role_name);
                }

            })
            // ->addColumn('type', function ($broadcast) {
            //     if($broadcast->user_id != ''){
            //         $type = 'Individual';
            //     }else{
            //         $type = 'Collective';
            //     }
            //     return $type;
            // })
            ->editColumn('created_at', function ($broadcast) {
                return date('d-m-Y h:i:s A', strtotime($broadcast->created_at));
            })
            ->addColumn('msg', function ($broadcast) {
                return $broadcast->message;
            })
            ->addColumn('actions', function ($broadcast) {
                return view('broadcast.action', ['broadcast' => $broadcast]);
            })
            ->rawColumns(['actions'])
            ->make(true);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $roles = Role::whereNotIn('name', ['super_admin'])->get();
        $accounts = Account::get();
        $tuition_centers = TuitionCentre::get();
        return view('broadcast.create', compact('roles','accounts','tuition_centers'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $broadcast = new Broadcast();
        if($request->send_to == 'user_role'){
            $roles = Role::whereIn('id', $request->role)->pluck('name')->toArray();
            $role_ids = Role::whereIn('id', $request->role)->pluck('id')->toArray();
            $users = User::role($roles)->get();
            $role = implode(',', $role_ids);
            $broadcast->role_id = $role;
        }else{
            $users = User::whereIn('id',$request->user_id)->get();
            $role = implode(',', $request->user_id);
            $broadcast->user_id = $role;
        }
        $broadcast->message = $request->msg;
        if ($request->savesend == 1) {
            $broadcast->is_send = '1';
        }
        $broadcast->save();

        if ($request->savesend == 1) {
            foreach ($users as $key => $user) {
                $msg = $request->msg;
                $type = 1;
                $title = 'Broadcast Message';
                $user->notify(new StudentJoinClass($msg, $title, $type));

                $title = "Broadcast Message";
                $msg = $request->msg;
                Mail::to($user->email)->send(new StudentMail($title, $msg));
            }
        }

        if ($request->savesend == 1) {
            return redirect()->route('broadcast.index')->with('message', 'broadcast save and send successfully');
        }else{
            return redirect()->route('broadcast.index')->with('message', 'broadcast save successfully');
        }

    }

    public function BroadcastSend(Request $request, $id)
    {
        $broadcast = Broadcast::find($id);
        if($request->type){
            $broadcast->is_whatsapp_send = '1';
        }else{
            $broadcast->is_send = '1';
        }
        $broadcast->save();

        if($broadcast->role_id != ''){
            $role_ids = explode(',', $broadcast->role_id);
            $roles = Role::whereIn('id', $role_ids)->pluck('name')->toArray();
            $users = User::role($roles)->get();
        }else{
                $user_ids = explode(',', $broadcast->user_id);
                $users = User::whereIn('id', $user_ids)->get();
        }

            foreach ($users as $key => $user) {
            if($user->roles->first()->name == 'tuition center'){
               $account = TuitionCentre::where('user_id',$user->id)->first();
            }else{
               $account = Account::where('user_id',$user->id)->first();
            }
            if($request->type){
                $phone = strlen($account->contact_number) == 10 ? '91'.$account->contact_number : $account->contact_number;
                $curl = curl_init();
                curl_setopt_array($curl, array(
                  CURLOPT_URL => 'https://graph.facebook.com/v17.0/103863959242173/messages',
                  CURLOPT_RETURNTRANSFER => true,
                  CURLOPT_ENCODING => '',
                  CURLOPT_MAXREDIRS => 10,
                  CURLOPT_TIMEOUT => 0,
                  CURLOPT_FOLLOWLOCATION => true,
                  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                  CURLOPT_CUSTOMREQUEST => 'POST',
                  CURLOPT_POSTFIELDS =>'{
                    "messaging_product": "whatsapp",
                    "to": '. $phone.',
                    "type": "template",
                    "template": {
                    "name": "'. env('APP_WHATSAPP_TEMPLATE').'",
                    "language": {
                        "code": "en_US"
                    },
                    "components": [
                        {
                            "type": "BODY",
                            "index": 0,
                            "parameters": [
                              {
                                "type": "text",
                                "text": "'.$broadcast->message.'"
                              }
                            ]
                        }
                    ]
            }
                  }',
                  CURLOPT_HTTPHEADER => array(
                    'Authorization: Bearer '.env('APP_WHATSAPP_TOKEN'),
                    'Content-Type: application/json'
                  ),
                ));

                $response = curl_exec($curl);
                $statusCode = curl_getinfo($curl,CURLINFO_HTTP_CODE);
                curl_close($curl);
            }else{
                $msg = $broadcast->message;
                $type = 1;
                $title = 'Broadcast Message';
                $user->notify(new StudentJoinClass($msg, $title, $type));

                $title = "Broadcast Message";
                $msg = $broadcast->message;
                Mail::to($user->email)->send(new StudentMail($title, $msg));
            }
        }
        return redirect()->route('broadcast.index')->with('message', 'broadcast send successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $broadcast = Broadcast::find($id);
        $role_ids = explode(',', $broadcast->role_id);
        $user_ids = explode(',', $broadcast->user_id);
        $roles = Role::whereNotIn('name', ['super_admin'])->get();
        $accounts = Account::get();
        $tuition_centers = TuitionCentre::get();
        return view('broadcast.edit', compact('roles', 'broadcast', 'role_ids','accounts','tuition_centers','user_ids'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $broadcast = Broadcast::find($id);
        if($request->send_to == 'user_role'){
            $roles = Role::whereIn('id', $request->role)->pluck('name')->toArray();
            $role_ids = Role::whereIn('id', $request->role)->pluck('id')->toArray();
            $users = User::role($roles)->get();
            $role = implode(',', $role_ids);
            $broadcast->role_id = $role;
            if($broadcast->user_id != ''){
                $broadcast->user_id = null;
            }
        }else{
            $users = User::whereIn('id',$request->user_id)->get();
            $role = implode(',', $request->user_id);
            $broadcast->user_id = $role;
            if($broadcast->role_id != ''){
                $broadcast->role_id = null;
            }
        }
        $broadcast->message = $request->msg;
        if ($request->savesend == 1) {
            $broadcast->is_send = '1';
        }
        $broadcast->save();

        if ($request->savesend == 1) {
            foreach ($users as $key => $user) {
                $msg = $request->msg;
                $type = 1;
                $title = 'Broadcast Message';
                $user->notify(new StudentJoinClass($msg, $title, $type));

                $title = "Broadcast Message";
                $msg = $request->msg;
                Mail::to($user->email)->send(new StudentMail($title, $msg));
            }
        }

        if ($request->savesend == 1) {
            return redirect()->route('broadcast.index')->with('message', 'broadcast update and send successfully');
        }else{
            return redirect()->route('broadcast.index')->with('message', 'broadcast update successfully');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $broadcast = Broadcast::find($id);
        $broadcast->delete();

        return redirect()->route('broadcast.index')->with('message', 'broadcast delete successfully');
    }
}
