<?php

namespace App\Http\Controllers;

use App\Models\Account;
use DB;
use Auth;
use DataTables;
use App\Models\User;
use App\Models\Tutor;
use App\Models\TuitionCentre;
use Spatie\Permission\Models\Role;
use Illuminate\Http\Request;

class CentreManagerController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function data()
    {
        $user = Auth::user();
        $centre = TuitionCentre::where('user_id', $user->id)->first();
        $tutors = Account::where('tuition_centre_id', $centre->id)->get();

        return DataTables::of($tutors)
            ->editColumn('name', function ($tutor) {
                return $tutor->first_name." ".$tutor->last_name;
            })
            ->editColumn('availiable_day', function ($tutor) {
                return "-";
            })
            ->editColumn('class_completed', function ($tutor) {
                return "-";
            })
            ->editColumn('subjects', function ($tutor) {
                return "-";
            })
            ->editColumn('created_at', function ($tutor) {
                return date('d-m-Y', strtotime($tutor->created_at));
            })
            ->editColumn('updated_at', function ($tutor) {
                return date('d-m-Y', strtotime($tutor->updated_at));
            })
            ->addColumn('actions', function ($tutor) {
                return view('tutors.action', ['tutor' => $tutor]);
            })
            // ->escapeColumns('actions')
            ->rawColumns(['actions'])->make(true);
    }

    public function index()
    {
        $centre = TuitionCentre::where('user_id', Auth::user()->id)->first();
        return view('centre_managers.index', compact('centre'));
    }

    public function subscriptionIndex()
    {
        return view('centre_managers.subscription');
    }

    public function subscriptionData(Request $request)
    {
        $user = Auth::user();
        if($request->data == 'tutor'){
            $centre = TuitionCentre::where('user_id', $user->id)->first();
            $ids = User::role('tutor')->pluck('id')->toArray();
            $tutors = Account::whereIn('user_id', $ids)->where('tuition_centre_id',$centre->id)->get();
        }else{
            $tutors = TuitionCentre::where('user_id', $user->id)->get();
            // $tutors = Account::where('tuition_centre_id', $centre->id)->get();
        }
        return DataTables::of($tutors)
            ->editColumn('name', function ($tutor) use ($request) {
                if($request->data == 'tutor'){
                return $tutor->first_name." ".$tutor->last_name;
                }else{
                return $tutor->name;
                }
            })
            ->editColumn('fee_str', function ($tutor) {
                return "-";
            })
            ->editColumn('invoice_date', function ($tutor) {
                return "-";
            })
            ->editColumn('invoice_number', function ($tutor) {
                return "-";
            })
            ->editColumn('payment_recieved', function ($tutor) {
                return "-";
            })
            ->editColumn('total_amt', function ($tutor) {
                return "-";
            })
            ->rawColumns(['actions'])->make(true);
    }
}
