<?php

namespace App\Http\Controllers;

use App\Models\Account;
use App\Models\ContactUs;
use App\Models\TuitionCentre;
use App\Models\User;
use Illuminate\Http\Request;
use DataTables;
use Auth;
use File;
class ContactUsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-support')->only('index', 'data');
        $this->middleware('permission:create-support')->only('create', 'store');
        $this->middleware('permission:edit-support')->only('edit', 'update');
        $this->middleware('permission:delete-support')->only('destroy');
        $this->middleware('permission:show-details-support')->only('show');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('contact_us.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('contact_us.create');
    }

    public function data(Request $request)
    {
        $users = User::pluck('id')->toArray();
        if(auth()->user()->roles->first()->name == 'super_admin' || auth()->user()->roles->first()->name == 'admin'){
            $values = ContactUs::orderBy('updated_at','desc')->whereIn('created_by_id',$users);
            if($request->service != ''){
                $values->where('service', $request->service);
            }
            $values = $values->get();
        }else{
            $values = ContactUs::where('created_by_id',auth()->user()->id)->whereIn('created_by_id',$users)->orderBy('updated_at','desc')->get();
        }
        return DataTables::of($values)
        ->addIndexColumn()
        // ->editColumn('name', function ($value) {
        //     if(auth()->user()->roles->first()->name == 'tuition center'){
        //         return TuitionCentre::find($value->created_by_id) ? TuitionCentre::find($value->created_by_id)->name : '';
        //     }else{
        //         return Account::find($value->created_by_id) ? Account::find($value->created_by_id)->first_name.' '.Account::find($value->created_by_id)->last_name : '';
        //     }
        // })
        ->editColumn('email', function ($value) {
            $user = User::find($value->created_by_id);
            if($user->roles->first()->name == 'tuition center'){
                $acc = TuitionCentre::where('user_id',$value->created_by_id)->first();
                $email = $acc ? $acc->email : '';
            }else{
                $acc = Account::where('user_id',$value->created_by_id)->first();
                $email = $acc ? $acc->email : '';
            }
            return $email;
        })
        ->editColumn('subject', function ($value) {
            return $value->subject;
        })
        ->editColumn('service', function ($value) {
            return $value->service == 'ADS' ? 'ADS Service' : $value->service ;
        })
        ->editColumn('message', function ($value) {
            return $value->message;
        })
        ->editColumn('created_at', function ($value) {
            return date('d-m-Y h:i:s A', strtotime($value->created_at));
        })
        ->editColumn('updated_at', function ($value) {
            return date('Y-m-d', strtotime($value->updated_at));
        })
        ->addColumn('action', function ($value) {
            return view('contact_us.action', ['value' => $value]);
        })
        ->rawColumns(['action'])->make(true);
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $store = new ContactUs();
        if ($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/support_banners/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/support_banners/' . $imageName, base64_decode($image));

            $store->logo = $imageName;
        }
        $store->service = $request->service;
        $store->subject = $request->subject;
        $store->message = $request->message;
        $store->created_by_id = auth()->user()->id;
        $store->save();
        return redirect()->route('contactus.index')->with('message','Support Created Successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data = ContactUs::find($id);
        $user = User::find($data->created_by_id);
        if($user->roles->first()->name == 'tuition center'){
            $acc = TuitionCentre::where('user_id',$data->created_by_id)->first();
            $name = $acc ? $acc->name : '';
            $email = $acc ? $acc->email : '';
            $role = 'tuition center';
        }else{
            $acc = Account::where('user_id',$data->created_by_id)->first();
            $name = $acc ? $acc->first_name.' '.$acc->last_name : '';
            $email = $acc ? $acc->email : '';
            $role = 'tutor';
        }
        return view('contact_us.show',compact('data','name','email','role','acc'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data = ContactUs::find($id);
        return view('contact_us.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // dd($request->all());
        $update = ContactUs::find($id);
        if ($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/support_banners/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/support_banners/' . $imageName, base64_decode($image));

            $update->logo = $imageName;
        }
        $update->service = $request->service;
        $update->subject = $request->subject;
        $update->message = $request->message;
        $update->save();
        return redirect()->route('contactus.index')->with('message','Support Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $contact = ContactUs::find($id);
        $contact->delete();
        return redirect()->route('contactus.index')->with('message', 'Support deleted successfully');
    }
}
