<?php

namespace App\Http\Controllers;

use App\Models\Account;
use Illuminate\Http\Request;
use App\Models\FrontContactUs;
use App\Models\ParentContact;
use DataTables;
use Auth;

class FrontContactUsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-contactus')->only('index', 'data');
        $this->middleware('permission:delete-contactus')->only('destroy');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('frontcontact_us.index');
    }

    public function Data(Request $request)
    {
        // dd(FrontContactUs::all());
        $values = FrontContactUs::all();
        return DataTables::of($values)
        ->addIndexColumn()
        ->editColumn('name', function ($value) {
            return $value ? $value->name : '';
        })
        ->editColumn('email', function ($value) {
            return $value ? $value->email : '';
        })
        ->editColumn('phone_no', function ($value) {
            return $value ? $value->phone_no : '';
        })
        ->editColumn('message', function ($value) {
            return $value ? $value->message : '';
        })
        ->editColumn('created_at', function ($value) {
            return date('d-m-Y h:i:s A', strtotime($value->created_at));
        })
        ->editColumn('updated_at', function ($value) {
            return date('Y-m-d', strtotime($value->updated_at));
        })
        ->addColumn('action', function ($value) {
            return view('frontcontact_us.action', ['value' => $value,'parent' => '']);
        })
        ->rawColumns(['action'])->make(true);
    }

    public function parentData(Request $request)
    {
        $parent_contact = ParentContact::orderBy('updated_at','desc')->get();

        return DataTables::of($parent_contact)
        ->addIndexColumn()
        ->editColumn('name', function ($parent_contact) {
            $acc = Account::find($parent_contact->parent_id);
            return $acc ? $acc->first_name.' '.$acc->last_name : '';
        })
        ->editColumn('email', function ($parent_contact) {
            $acc = Account::find($parent_contact->parent_id);
            return $acc ? $acc->email : '-';
        })
        ->editColumn('phone_no', function ($parent_contact) {
            $acc = Account::find($parent_contact->parent_id);
            return $acc ? ($acc->contact_number ? $acc->contact_number : '-') : '-';
        })
        ->editColumn('created_at', function ($parent_contact) {
            return date('d-m-Y h:i:s A', strtotime($parent_contact->created_at));
        })
        ->addColumn('updated_at', function ($parent_contact) {
            return date('Y-m-d', strtotime($parent_contact->updated_at));
        })
        ->addColumn('action', function ($parent_contact) {
            return view('frontcontact_us.action', ['value' => $parent_contact,'parent' => '1']);
        })
        ->rawColumns(['action'])->make(true);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request,$id)
    {
        if($request->parent == 1){
            $contact = ParentContact::find($id)->delete();
        }else{
            $values = FrontContactUs::find($id);
            $values->delete();
        }
        return redirect()->route('frontcontactus.index')->with('message', 'Delete contact us successfully');
    }
}
