<?php

namespace App\Http\Controllers;

use App\Models\Lessons;
use App\Models\Levels;
use App\Models\Subject;
use App\Models\Topic;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class LessonController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-lesson')->only('index', 'getData');
        $this->middleware('permission:create-lesson')->only('create', 'store');
        $this->middleware('permission:edit-lesson')->only('edit', 'update');
        $this->middleware('permission:delete-lesson')->only('destroy');
    }

    public function index()
    {
        $levels = Levels::all();
        $subjects = Subject::all();
        $topics = Topic::all();
        return view('lessons.index2', compact('levels', 'subjects', 'topics'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function getData(Request $request)
    {
        // dd($request->all());
        $lessons = Lessons::orderBy('updated_at','desc');

        if ($request->level != '') {
            $lessons->where('level_id', $request->level);
        }

        if ($request->subject != '') {
            $lessons->where('subject_id', $request->subject);
        }

        if ($request->topic != '') {
            $lessons->where('topic_id', $request->topic);
        }

        $lessons->get();

        return DataTables::of($lessons)
        ->editColumn('level_id', function ($lessons) {
            return Levels::find($lessons->level_id) ? Levels::find($lessons->level_id)->name : '';
        })
        ->editColumn('subject_id', function ($lessons) {
           return Subject::find($lessons->subject_id) ? Subject::find($lessons->subject_id)->name : '';
        })
        ->editColumn('topic_id', function ($lessons) {
           return Topic::find($lessons->topic_id) ? Topic::find($lessons->topic_id)->name : '';
        })
        ->addColumn('updated_at', function ($admin) {
            return date('Y-m-d', strtotime($admin->updated_at));
        })
        ->addColumn('actions', function ($lessons) {
            return view('lessons.action', ['lessons' => $lessons]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    public function create()
    {
        $levels = Levels::all();
        $subjects = Subject::all();
        $topics = Topic::all();
        return view('lessons.create',compact('topics','levels','subjects'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'level' => 'required',
            'subject' => 'required',
            'topic' => 'required',
            'lesson' => 'required|min:3|max:50',
        ]);
        $find = Lessons::where('level_id', $request->level)->where('topic_id', $request->topic)->where('subject_id', $request->subject)->where('name',$request->lesson)->first();
        if($find != ''){
        return redirect()->back()->withErrors('Lesson Already Exist On This Level & Subject!')->withInput();
        }
        $Lessons = new Lessons;
        $Lessons->name = $request->lesson;
        $Lessons->level_id = $request->level;
        $Lessons->topic_id = $request->topic;
        $Lessons->subject_id = $request->subject;
        $Lessons->save();
        return redirect()->route('lesson.index')->with('message', 'Lesson created successfully');
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $levels = Levels::all();
        $subjects = Subject::all();
        $topics = Topic::all();
        $lessons = Lessons::find($id);
        return view('lessons.edit',compact('lessons','levels','subjects','topics'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'level' => 'required',
            'subject' => 'required',
            'topic' => 'required',
            'lesson' => 'required|min:3|max:50|unique:lessons,name,'.$id,
        ]);
        $find = Lessons::where('id','!=',$id)->where('level_id', $request->level)->where('topic_id', $request->topic)->where('subject_id', $request->subject)->where('name',$request->lesson)->first();
        if($find != ''){
        return redirect()->back()->withErrors('Lesson Already Exist On This Level & Subject!')->withInput();
        }
        $Lessons = Lessons::find($id);
        $Lessons->name = $request->lesson;
        $Lessons->level_id = $request->level;
        $Lessons->topic_id = $request->topic;
        $Lessons->subject_id = $request->subject;
        $Lessons->save();
        return redirect()->route('lesson.index')->with('message', 'Lesson Updated successfully');
    }

    public function Samename(Request $request){
        $find_name = '';
        if($request->from == 'level'){
             if($request->id){
                $find_name = Levels::where('name',$request->name)->where('id','!=',$request->id)->first();
             }else{
                $find_name = Levels::where('name',$request->name)->first();
             }
        }elseif($request->from == 'subject'){
            if($request->id){
                if($request->level != ''){
                    $find_name = Subject::where('name',$request->name)->where('level_id', $request->level)->where('id','!=',$request->id)->first();
                }else{
                    $find_name = Subject::where('name',$request->name)->where('id','!=',$request->id)->first();
                }
             }else{
                if($request->level != ''){
                    $find_name = Subject::where('name',$request->name)->where('level_id', $request->level)->first();
                }
                // else{
                //     $find_name = Subject::where('name',$request->name)->first();
                // }
             }
        }
         if($find_name != ''){
            $return =  false;
           }else{
            $return= true;
           }
         echo json_encode($return);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Lessons $lesson)
    {
        $lesson->delete() ;
        return redirect()->route('lesson.index')->with('message', 'Lesson Deleted successfully');
    }
}
