<?php

namespace App\Http\Controllers;

use App\Models\Levels;
use DataTables;
use App\Models\Subject;
use Illuminate\Http\Request;

class LevelController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-level')->only('index', 'getData');
        $this->middleware('permission:create-level')->only('create', 'store');
        $this->middleware('permission:edit-level')->only('edit', 'update');
        $this->middleware('permission:delete-level')->only('destroy');
    }

    public function index()
    {
        return view('levels.index');
    }

    public function getData()
    {
        $levels = Levels::orderBy('updated_at','desc')->get();
        return DataTables::of($levels)
        ->editColumn('created_at', function ($level) {
            return date('d-m-Y', strtotime($level->created_at));
        })
        ->addColumn('updated_at', function ($admin) {
            return date('Y-m-d', strtotime($admin->updated_at));
        })
        ->addColumn('actions', function ($level) {
            return view('levels.action', ['level' => $level]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('levels.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|unique:levels,name,NULL,id',
        ], [
            'name.required' => 'Name of Level is required.'
        ]);
        $level = new Levels;
        $level->name = $request->name;
        $level->save();
        return redirect()->route('level.index')->with('message', 'Level created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $level = Levels::find($id);
        return view('levels.edit',compact('level'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Levels $level)
    {
        $this->validate($request, [
            'name' => 'required|unique:levels,name,'.$level->id,
        ], [
            'name.required' => 'Name of Level is required.'
        ]);
        $levelUpdate = $level ;
        $levelUpdate->name = $request->name;
        $levelUpdate->save();
        return redirect()->route('level.index')->with('message', 'Level Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Levels $level)
    {
        $level->delete() ;
        return redirect()->route('level.index')->with('message', 'Level Deleted successfully');
    }
}
