<?php

namespace App\Http\Controllers;

use App\Models\ClasstuitionCentrelink;
use App\Models\MultipleCentre;
use App\Models\ScheduleClass;
use App\Models\TuitionCentre;
use Illuminate\Http\Request;
use DataTables;
use DateTime;
use DatePeriod;
use DateInterval;
use Auth;

class MultipleCentreController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-multiplecentre')->only('index', 'data');
        $this->middleware('permission:create-multiplecentre')->only('create','store');
        $this->middleware('permission:edit-multiplecentre')->only('edit', 'update');
        $this->middleware('permission:delete-multiplecentre')->only('destroy');
    }
    public function index()
    {
        return view('multiple-centres.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function data(Request $request)
    {
        $acc = TuitionCentre::where('user_id',auth()->user()->id)->first();
        $center = MultipleCentre::where('center_id',$acc->id)->orderBy('updated_at','desc')->get();
        // dd($center);
        return DataTables::of($center)
        ->editColumn('created_at', function ($center) {
            return date('d-m-Y', strtotime($center->created_at));
        })
        ->addColumn('updated_at', function ($center) {
            return date('Y-m-d', strtotime($center->updated_at));
        })
        ->addColumn('actions', function ($center) {
            return view('multiple-centres.action', ['centre' => $center]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    public function create()
    {
        return view('multiple-centres.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $acc = TuitionCentre::where('user_id',auth()->user()->id)->first();
        $centre = new MultipleCentre();
        $centre->name = $request->centre_name;
        $centre->center_id = $acc->id;
        $centre->save();
        return redirect()->route('multiplecentre.index')->with('message', 'Centre created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $centre = MultipleCentre::find($id);
        return view('multiple-centres.edit',compact('centre'));
    }

    public function Get_calender(Request $request)
    {
            $centre = TuitionCentre::where('user_id', Auth::user()->id)->first();
            $index = 0;
            $grp_id = 0;
            if($request->center != ''){
                if($request->center == 'current'){
                    $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->whereNull('center_id')->pluck('class_id')->toArray();
                }else{
                    $tutor_ids = ClasstuitionCentrelink::where('center_id', $request->center)->pluck('class_id')->toArray();
                }
            }else{
                $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->pluck('class_id')->toArray();
            }
            //upcoming
            $upcoming_class1 = ScheduleClass::whereIn('id',$tutor_ids)->where('endRecurring_date','=',date('Y-m-d'))->where('start_time','>=',date('H:i:s'))->pluck('id')->toArray();
            $upcoming_class2 = ScheduleClass::whereIn('id',$tutor_ids)->where('endRecurring_date','>',date('Y-m-d'))->pluck('id')->toArray();
            $upcoming = array_merge($upcoming_class1,$upcoming_class2);

            $classes = ScheduleClass::whereIn('id', $upcoming)->orderBy('id','DESC')->get();
            $scheduleClasses = [];
            foreach ($classes as $key => $value) {
                // if ($value->class_date >= date('Y-m-d')) {
                    $scheduleClasses[] = $value;
                // }
            }
            $final_array = array(array());
            $loc_arr = array();

            foreach($scheduleClasses as $class){
                $start_day = date('D',strtotime($class->class_date));
                $is_weekday = $start_day == 'Sat' || $start_day == 'Sun' ? '0' : '1';
                if($class->is_recurring){
                    if($class->everyWeekday){
                        $interval = DateInterval::createFromDateString('1 day');
                        $period = new DatePeriod(new DateTime($class->class_date), $interval, new DateTime($class->endRecurring_date.' +1 day'));

                        foreach ($period as $dt) {
                            if($is_weekday){
                                if(!($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun')){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d'),
                                        'start_time' => date('h:i A',strtotime($class->start_time))
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            } else {
                                if($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun'){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d'),
                                        'start_time' => date('h:i A',strtotime($class->start_time))
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            }
                        }
                    } else if($class->everyWeek){
                        $interval = DateInterval::createFromDateString('1 week');
                        $period = new DatePeriod(new DateTime($class->class_date), $interval, new DateTime($class->endRecurring_date.' +1 day'));

                        foreach ($period as $dt) {
                            $loc_arr = array(
                                'grp' => $grp_id,
                                'id' => $class->id,
                                'name' => $class->name,
                                'class_date' => $dt->format('Y-m-d'),
                                'start_time' => date('h:i A',strtotime($class->start_time))
                            );
                            $final_array[$index++] = $loc_arr;
                        }
                    } else { //MONTHLY
                        $interval = DateInterval::createFromDateString('1 month');
                        $period = new DatePeriod(new DateTime($class->class_date), $interval, new DateTime($class->endRecurring_date.' +1 day'));

                        foreach ($period as $dt) {
                            if($is_weekday){
                                if(!($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun')){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d'),
                                        'start_time' => date('h:i A',strtotime($class->start_time))
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            } else {
                                if($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun'){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d'),
                                        'start_time' => date('h:i A',strtotime($class->start_time))
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            }
                        }
                    }
                } else {
                    if($class->start_time < date('H:i:s')){
                        $date = date('Y-m-d',strtotime('+1 days'));
                    }else{
                        $date = date('Y-m-d');
                    }
                    $loc_arr = array(
                        'grp' => $grp_id,
                        'id' => $class->id,
                        'name' => $class->name,
                        'class_date' => $date,
                        'start_time' => date('h:i A',strtotime($class->start_time))
                    );
                    $final_array[$index++] = $loc_arr;
                }
                $grp_id++;
            }
            $scheduleClasses = $final_array;
            return ['scheduleClasses' => $scheduleClasses];
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $acc = TuitionCentre::where('user_id',auth()->user()->id)->first();
        $update = MultipleCentre::find($id);
        $update->name = $request->centre_name;
        $update->center_id = $acc->id;
        $update->save();
        return redirect()->route('multiplecentre.index')->with('message', 'Centre Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $delete = MultipleCentre::find($id)->delete();
        $remove_id = ClasstuitionCentrelink::where('center_id',$id)->update(['center_id' => '']);
        return redirect()->route('multiplecentre.index')->with('message', 'Centre Deleted successfully');
    }
}
