<?php

namespace App\Http\Controllers;

use App\Mail\ParentContactMail;
use App\Mail\StudentMail;
use App\Models\Account;
use App\Models\ParentContact;
use Illuminate\Http\Request;
use DataTables;
use App\Models\User;
use App\Notifications\StudentJoinClass;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Mail;

class ParentContactUsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-parent-contact')->only('index', 'data');
        $this->middleware('permission:create-parent-contact')->only('create','store');
        $this->middleware('permission:edit-parent-contact')->only('edit', 'update');
        $this->middleware('permission:delete-parent-contact')->only('destroy');
        $this->middleware('permission:send-mail-parent-contact')->only('ContactSend');
        $this->middleware('permission:send-whatsapp-parent-contact')->only('ContactSend');
    }
    public function index()
    {
        return view('parent_contact_us.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('parent_contact_us.create');
    }

    public function data()
    {
        $user = Account::where('user_id',auth()->user()->id)->first();
        $parent_contact = ParentContact::where('parent_id',$user->id)->orderBy('updated_at','desc')->get();
        return DataTables::of($parent_contact)
        ->addIndexColumn()
        ->editColumn('created_at', function ($parent_contact) {
            return date('d-m-Y', strtotime($parent_contact->created_at));
        })
        ->addColumn('updated_at', function ($parent_contact) {
            return date('Y-m-d', strtotime($parent_contact->updated_at));
        })
        ->addColumn('actions', function ($parent_contact) {
            return view('parent_contact_us.action', ['parent_contact' => $parent_contact]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $account = Account::where('user_id',auth()->user()->id)->first();
        $store = new ParentContact();
        $store->parent_id = $account->id;
        $store->message = $request->message;
        if ($request->savesend == 1) {
            $store->is_whatsapp_send = '1';
            $store->is_send = '1';
        }
        $store->save();

        if ($request->savesend == 1) {
            $account = Account::where('email','admin@test.com')->first();
            $user = User::find($account->user_id);
            $phone = strlen($account->contact_number) == 10 ? '91'.$account->contact_number : $account->contact_number;
            //whatsapp
            $curl = curl_init();
            curl_setopt_array($curl, array(
              CURLOPT_URL => 'https://graph.facebook.com/v17.0/103863959242173/messages',
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => '',
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => 'POST',
              CURLOPT_POSTFIELDS =>'{
                "messaging_product": "whatsapp",
                "to": '. $phone.',
                "type": "template",
                "template": {
                "name": "'. env('APP_WHATSAPP_TEMPLATE').'",
                "language": {
                    "code": "en_US"
                },
                "components": [
                    {
                        "type": "body",
                        "index": 0,
                        "parameters": [
                          {
                            "type": "text",
                            "text": "*Message :* '.$store->message.'"
                          }
                        ]
                    }
                ]
        }
              }',
              CURLOPT_HTTPHEADER => array(
                'Authorization: Bearer '.env('APP_WHATSAPP_TOKEN'),
                'Content-Type: application/json'
              ),
            ));

            $response = curl_exec($curl);
            $statusCode = curl_getinfo($curl,CURLINFO_HTTP_CODE);
            curl_close($curl);
            //mail
            $title = "Parent Message";
                $msg = $store->message;
                $parent = Account::where('user_id',auth()->user()->id)->first();
                $parent_email = $parent->email;
                $parent_name = $parent->first_name.' '.$parent->last_name;
                Mail::send('emails.parent_contact_mail', ['title' => $title, 'msg' => $msg,'parent_name' => $parent_name,'parent_email' => $parent_email], function ($m) use ($user,$parent,$account) {
                    $m->from($parent->email, $parent->first_name.' '.$parent->last_name);
                    $m->to($user->email, $account->first_name.' '.$account->last_name)->subject('Parent Contact Mail');
                });

            return redirect()->route('parent-contact.index')->with('message', 'Contact Message save and send successfully');
        }else{
            return redirect()->route('parent-contact.index')->with('message', 'Contact Message Added successfully');
        }
    }

    public function ContactSend(Request $request, $id)
    {
        $contact = ParentContact::find($id);
        if($request->type){
            $contact->is_whatsapp_send = '1';
            $message = 'WhatsApp Message send successfully';
        }else{
            $contact->is_send = '1';
            $message = 'Mail send successfully';
        }
        $contact->save();

        $account = Account::where('email','admin@test.com')->first();
        $user = User::find($account->user_id);
            if($request->type){
                $phone = strlen($account->contact_number) == 10 ? '91'.$account->contact_number : $account->contact_number;
                $curl = curl_init();
                curl_setopt_array($curl, array(
                  CURLOPT_URL => 'https://graph.facebook.com/v17.0/103863959242173/messages',
                  CURLOPT_RETURNTRANSFER => true,
                  CURLOPT_ENCODING => '',
                  CURLOPT_MAXREDIRS => 10,
                  CURLOPT_TIMEOUT => 0,
                  CURLOPT_FOLLOWLOCATION => true,
                  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                  CURLOPT_CUSTOMREQUEST => 'POST',
                  CURLOPT_POSTFIELDS =>'{
                    "messaging_product": "whatsapp",
                    "to": '. $phone.',
                    "type": "template",
                    "template": {
                    "name": "'. env('APP_WHATSAPP_TEMPLATE').'",
                    "language": {
                        "code": "en_US"
                    },
                    "components": [
                        {
                            "type": "body",
                            "index": 0,
                            "parameters": [
                              {
                                "type": "text",
                                "text": "*Message :* '.$contact->message.'"
                              }
                            ]
                        }
                    ]
            }
                  }',
                  CURLOPT_HTTPHEADER => array(
                    'Authorization: Bearer '.env('APP_WHATSAPP_TOKEN'),
                    'Content-Type: application/json'
                  ),
                ));

                $response = curl_exec($curl);
                $statusCode = curl_getinfo($curl,CURLINFO_HTTP_CODE);
                curl_close($curl);
            }else{
                $title = "Parent Message";
                $msg = $contact->message;
                $parent = Account::where('user_id',auth()->user()->id)->first();
                $parent_email = $parent->email;
                $parent_name = $parent->first_name.' '.$parent->last_name;
                Mail::send('emails.parent_contact_mail', ['title' => $title, 'msg' => $msg,'parent_name' => $parent_name,'parent_email' => $parent_email], function ($m) use ($user,$parent,$account) {
                    $m->from($parent->email, $parent->first_name.' '.$parent->last_name);
                    $m->to($user->email, $account->first_name.' '.$account->last_name)->subject('Parent Contact Mail');
                });
                // Mail::to($user->email)->from('youremail@example.com', 'Your Name')->subject('Hi there')->send(new ParentContactMail($title, $msg,$parent_name,$parent_email));
            }

        return redirect()->route('parent-contact.index')->with('message', $message);
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $contact = ParentContact::find($id);
        return view('parent_contact_us.update',compact('contact'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // dd($request->all());
        $account = Account::where('user_id',auth()->user()->id)->first();
        $update = ParentContact::find($id);
        $update->parent_id = $account->id;
        $update->message = $request->message;
        $update->save();
        return redirect()->route('parent-contact.index')->with('message', 'Contact Message Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $contact = ParentContact::find($id)->delete();
        return redirect()->route('parent-contact.index')->with('message', 'Contact Message Deleted successfully');
    }
}
