<?php

namespace App\Http\Controllers;

use App\Models\Account;
use App\Models\User;
use Auth;
use App\Models\TuitionCentre;
use DB;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Role;
use DataTables;
use Illuminate\Http\Request;
use App\Mail\ParentMail;
use App\Mail\StudentClassJoin;
use App\Models\ScheduleClass;
use App\Models\StudentClass;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Mail;
use Session;
use File;


class ParentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-parent')->only('index', 'data');
        $this->middleware('permission:create-parent')->only('create','store');
        $this->middleware('permission:edit-parent')->only('edit', 'update');
        $this->middleware('permission:delete-parent')->only('destroy');
        $this->middleware('permission:view-student')->only('student_dashboard');
        $this->middleware('permission:show-details-parent')->only('show');
    }

    public function index()
    {
        return view('parents.admin_index');
    }

    public function parentlogout(Request $request) {
        // dd($request->all());
        Cookie::queue(Cookie::forget('login',null,'.swotfishdemo.cc'));
        Auth::logout();
        return redirect('sign-in?user='.$request->user);
    }

    public function data(Request $request)
    {
        // dd($request->all());
        $user = User::role('parent');

        if($request->status != ''){
            $active_acc = Account::where('status', $request->status)->pluck('user_id')->toArray();
            $user->whereIn('id', $active_acc);
        }

        $user = $user->orderBy('updated_at','desc')->get();
        return DataTables::of($user)
        ->editColumn('created_at', function ($parent) {
            return date('d-m-Y', strtotime($parent->created_at));
        })
        ->addColumn('updated_at', function ($parent) {
            return date('Y-m-d', strtotime($parent->updated_at));
        })
        ->editColumn('contact_number', function ($parent) {
             $account = Account::where('user_id',$parent->id)->first();
             return $account->contact_number;
        })
        ->addColumn('students', function ($parent) {
            $account = Account::where('user_id',$parent->id)->first();
            $students = Account::where('parent_id',$account->id)->get();
            $name = [];
            foreach($students as $student){
                array_push($name,$student->first_name.' '.$student->last_name);
            }
            return implode(',',$name);
        })
        ->addColumn('status', function ($parent) {
            $account = Account::where('user_id',$parent->id)->first();
            if($account->status == 'inactive'){
                return '<a class="btn btn-warning" onclick="return confirm(\'Are you sure want to Active ?\');" style="border:none;color:#ce7906;background:#ed921847;" href="'.route('account.changestatus',['id' => $parent->id,'value' => 1,'user'=>'Parent']).'">Inactive</a>';
            }else{
                return '<a class="btn btn-success" onclick="return confirm(\'Are you sure want to Inactive ?\');" style="border:none;color:#26ab38;background:#26ab3863;" href="'.route('account.changestatus',['id' => $parent->id,'value' => 0,'user'=>'Parent']).'">Active</a>';
            }
        })
        ->editColumn('email', function ($parent) {
            return $parent->email;
        })
        ->addColumn('actions', function ($parent) {
            return view('parents.action', ['admin' => $parent]);
        })
        ->escapeColumns('ratings')
        ->rawColumns(['actions','status'])->make(true);
    }

    public function student_dashboard(Request $request){
        $parent = Account::where('user_id', Auth::user()->id)->first();
        $student = Account::where('parent_id',$parent->id)->get()->count();
        $class = $request->class_id;
        $contact_number = 65;
        return view('parents.student_dashboard',compact('parent','student','class','contact_number'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        $edit = 0;
        if($request->show){
            $show = 1;
        }else{
            $show = 0;
        }
        $contact_number = 65;
        return view('parents.create',compact('edit','show','contact_number'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $this->validate($request, [
            // 'profile_picture' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'gender' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email',
            'contact_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:6',
        ]);

        $user = User::create([
            'name' => $request->first_name." ".$request->last_name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);
        // $user->assignRole($request->role_id);
        $user->assignRole('parent');

        $updated_logo_name = "";
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

            $updated_logo_name = $imageName;
        }

        $parent_details = array(
            'user_id' => $user->id,
            'profile_picture' => $updated_logo_name,
            'first_name' => $request->first_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'street_name' => $request->street_name,
            'state' => $request->state,
            'city' => $request->city,
            'zip_code' => $request->zip_code,
            'email' => $request->email,
            'contact_number' => $request->countryCode.$request->contact_number,
            'remarks' => $request->remarks,
            'status' => $request->status
        );
        DB::table('accounts')->insert($parent_details);

        $title = "Create Parent";
        $msg = $request->first_name.' Parent created';

        Mail::to($request->email)->send(new ParentMail($title, $msg));

        $users = Auth::user();
        if($users == ''){
            Auth::loginUsingId($user->id);
            return redirect()->route('home')->with('message','You Have Registered Successfully');
        }else{
            return redirect()->route('parent.index')->with('message', 'Parent created successfully');
        }
    }

    public function storeParentAccount(Request $request)
    {
        // dd($request->all());
        $users = Auth::user();
        if($users != ''){
            return redirect()->route('home');
        }
        $this->validate($request, [
            'first_name' => 'required|min:3|max:50',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
        ]);

        $user = User::create([
            'name' => $request->first_name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);
        $user->assignRole('parent');

        $parent_details = array(
            'user_id' => $user->id,
            'first_name' => $request->first_name,
            'email' => $request->email,
        );
        DB::table('accounts')->insert($parent_details);

        $admin = DB::table('users')
                ->select('users.email')
                ->leftJoin('model_has_roles','users.id','=','model_has_roles.model_id')
                ->leftJoin('roles','roles.id','=','model_has_roles.role_id')
                ->where('roles.id',6)
                ->first();
        $parent_details = Account::where('user_id',$user->id)->first();
        Auth::loginUsingId($user->id);
        $title = "Create Parent";
        $msg = $request->first_name.' Parent created';
        Mail::to($admin->email)->send(new ParentMail($title, $msg));
        return redirect()->route('home',['class_id' => $request->class])->with('message','Parent Registered Successfully');
    }

    public function signin(Request $request){
        $user = $request->user;
        session()->put('classId', $request->class_id);
        return view('parents.sign_in', compact('user'));
    }

    public function getTutor(Request $request)
    {
        if($request->type == 'tutor'){
            $tutor = User::role('tutor')->pluck('id')->toArray();
            $users = Account::whereIn('user_id', $tutor)->orderBy('updated_at','desc')->get();
        }else{
            $users = TuitionCentre::all();
        }
        return [
            'users' => $users,
            'type'  => $request->type
        ];
    }

    public function edit(Request $request,$id)
    {
        $admin = User::find($id);
        $admin_details = DB::table('accounts')->where('user_id',$id)->first();
        $roles = Role::all();
        $edit = 1;
        $contact_number = substr($admin_details->contact_number, 0, -10) == '' ? 65 : substr($admin_details->contact_number, 0, -10);
        if($request->from_profile){
            $previous = route('parent.show',$id);
            $from_profile = 1;
            return view('parents.edit_parent', compact('roles', 'admin','admin_details','edit','previous','from_profile','contact_number'));
        }else{
            $previous = route('parent.index');
            $from_profile = 0;
            return view('parents.edit', compact('roles', 'admin','admin_details','edit','previous','from_profile','contact_number'));
        }

    }

    public function update(Request $request,$id)
    {
        // dd($request,$id);
        $sup = DB::table('accounts')->where('user_id',$id)->first();
        $sup_id = $sup ? $sup->id : '';
        $this->validate($request, [
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'gender' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            // 'zip_code' => 'required',
            'email' => 'required|email|unique:users,email,'.$id,
            'contact_number' => 'required',
        ]);

        $user = User::find($id);
        // $user->syncRoles($request->role_id);

        $updated_logo_name = "";
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

            $updated_logo_name = $imageName;
        }

        // $updated_logo_name = "";
        // if ($logo = $request->file('profile_picture')) {
        //     $logo_name = $request->first_name.$request->file('profile_picture')->getClientOriginalName();
        //     $target_path = public_path('/profile_pictures/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $updated_logo_name = $logo_name;
        //     }
        // }

        if($request->password != ""){
            if($request->password != $request->password_confirmation){
                return redirect()->back()->withErrors(["Confirm Password didn't match"])->withInput();
            } else {
                $user = User::where('id', $id)->update([
                    'name' => $request->first_name." ".$request->last_name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password)
                ]);
            }
        } else {
            $user = User::where('id', $id)->update([
                'name' => $request->first_name." ".$request->last_name,
                    'email' => $request->email,
            ]);
        }
        $find_admin = DB::table('accounts')->where('user_id',$id)->first();
        if($find_admin != ''){
        if($updated_logo_name){
            $parent_details = array(
                'profile_picture' => $updated_logo_name,
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'gender' => $request->gender,
                'street_name' => $request->street_name,
                'state' => $request->state,
                'city' => $request->city,
                'zip_code' => $request->zip_code,
                'email' => $request->email,
                'contact_number' => $request->countryCode.$request->contact_number,
                'remarks' => $request->remarks,
                'status' => $request->status
            );
        } else {
            $parent_details = array(
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'gender' => $request->gender,
                'street_name' => $request->street_name,
                'state' => $request->state,
                'city' => $request->city,
                'zip_code' => $request->zip_code,
                'email' => $request->email,
                'contact_number' => $request->countryCode.$request->contact_number,
                'remarks' => $request->remarks,
                'status' => $request->status
            );
        }
        DB::table('accounts')->where('user_id',$id)->update($parent_details);

    }else{
        $parent_details = array(
            'user_id' => $id,
            'profile_picture' => $updated_logo_name,
            'first_name' => $request->first_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'street_name' => $request->street_name,
            'state' => $request->state,
            'city' => $request->city,
            'zip_code' => $request->zip_code,
            'email' => $request->email,
            'contact_number' => $request->countryCode.$request->contact_number,
            'remarks' => $request->remarks,
            'status' => $request->status
        );
        DB::table('accounts')->insert($parent_details);
    }
        $account = Account::where('user_id',$id)->first();
        if($request->from_profile == 1){
            return redirect()->route('parent.show',$id)->with('message', 'Profile updated successfully');
        }else{
            return redirect()->route('parent.index')->with('message', 'Parent updated successfully');
        }

    }

    public function destroy(Request $request, $id)
    {
        User::find($id)->delete();
        Account::where('user_id',$id)->delete();
        return redirect()->route('parent.index')->with('message', 'Parent deleted successfully');
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Request $request,$id)
    {
        if($request->show){
            $show = $request->show;
        }else{
            $show = '';
        }
        $role = 'parent';
        $previous = route('parent.index');
        $edit_route = route('parent.edit', $id);
        $value = Account::where('user_id',$id)->first();
        if(auth()->user()->roles->first()->name == 'parent'){
            $previous = route('home');
        }
        return view('parents.show',compact('value','show','role','previous','edit_route'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
}
