<?php

namespace App\Http\Controllers;

use DB;
use DataTables;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;
use App\Models\User;

class RolePermissionController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
        $roles = Role::where('name','!=','super_admin')->get();
        return view('roles.index',compact('roles'));

    }

    public function data() {
        $roles = Role::whereNotIn('name', ['super_admin'])->get();
        return DataTables::of($roles)
            ->editColumn('name', function ($role) {
               return $role->name == 'tuition center' ? 'Tuition Centre' : str_replace('_', ' ', ucwords($role->name));
            })
            ->addColumn('actions', function ($role) {
                return view('roles.action', ['role' => $role]);
            })
            ->rawColumns(['actions'])->make(true);
    }

    public function Check(Request $request)
    {
        // dd($request->all());
        $check = Role::where('name',$request->role_name)->first();
        if($check != ''){
            $return =  false;
        }else{
            $return= true;
        }
        echo json_encode($return);
    }

    public function create(Request $request)
    {
        $role = '';
        $permissions = [];
        return view('roles.role_index',compact('role','permissions'));
    }

    public function Roleindex(Request $request)
    {
        $role = Role::where('name', $request->role)->first();
        $permissions = DB::table('role_has_permissions')->where('role_id',$role->id)->pluck('permission_id')->toArray();
        return view('roles.role_index',compact('role','permissions'));
    }

    public function updatePermission(Request $request)
    {
        // dd($request->all());
        if($request->role_id == ''){
            $store = new Role();
            $store->name = $request->role_name;
            $store->save();

            $role_id = $store->id;
        }else{
            $role_id = $request->role_id;
        }
        $my_perms = $request->perms;

        $permission_id = Permission::pluck('id')->toArray();
        $roles = Role::find($role_id);
        $numbers = [];
        if($roles->name == 'parent'){
            $numbers = [26,15,13,16];
        }elseif($roles->name == 'student'){
            $numbers = [26,27,16,20,18,49];
        }elseif($roles->name == 'tutor'){
            $numbers = [6,7,8,9,10];
        }elseif($roles->name == 'tuition center'){
            $numbers = [1,2,3,4,5];
        }
        if($roles->name != 'admin'){
            foreach($numbers as $number){
                array_push($my_perms,$number);
            }
        }
        if($my_perms == ''){
            $my_perms = [];
        }
        foreach($permission_id as $key => $permission_ids){
        $arr = array('permission_id' => $permission_ids, 'role_id' => $role_id);
        $roles->givePermissionTo($permission_ids);
        if(in_array($permission_ids,$my_perms)){
            $find = DB::table('role_has_permissions')->where('permission_id',$permission_ids)->where('role_id',$role_id)->first();
            if($find->permission_id == ''){
                DB::table('role_has_permissions')->insert($arr);
            }
        }else {
            DB::table('role_has_permissions')->where($arr)->delete();
        }
        }
        return redirect()->route('role.index')->with('message','Role Permissions Updated Successfully!');
    }

    public function destroy($id)
    {
        //dd($id);
        $role = Role::find($id);
        $role->delete();
        return redirect()->route('role.index')->with('message', 'Role deleted successfully!');
    }
}
