<?php

namespace App\Http\Controllers;

use App\Models\Account;
use App\Models\ClasstuitionCentrelink;
use App\Models\Classtutorlink;
use App\Models\Lessons;
use Auth;
use DateTime;
use DatePeriod;
use DateInterval;
use DataTables;
use File;
use App\Models\Topic;
use App\Models\Subject;
use Illuminate\Http\Request;
use App\Models\ScheduleClass;
use App\Models\TuitionCentre;
use App\Models\SpecialClassSchedule;
use App\Models\RecurrClassSchedule;

class ScheduleClassController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function data()
    {
        $scheduleClasses = ScheduleClass::orderBy('id','DESC')->get();
        return DataTables::of($scheduleClasses)
        ->editColumn('type_id', function ($scheduleClasses) {
            if($scheduleClasses->type_id == "1"){
                return 'Online Group Class' ;
            }else if($scheduleClasses->type_id == "2"){
                return 'Online 1 -1 Class' ;
            }else if($scheduleClasses->type_id == "3"){
                return 'Offline Group Class' ;
            }else{
                return 'Offline 1 -1 Class' ;
            }
        })
        ->editColumn('class_date', function ($scheduleClasses) {
            if($scheduleClasses->class_date == "" || $scheduleClasses->class_date == null){
                return date('d-m-Y', strtotime($scheduleClasses->created_at));
            }else{
                return date('d-m-Y', strtotime($scheduleClasses->class_date));
            }
        })
        ->addColumn('class_time', function ($scheduleClasses) {
            return $scheduleClasses->start_time . ' - ' . $scheduleClasses->end_time ;
        })
        ->editColumn('subject_id', function ($scheduleClasses) {
           return Subject::find($scheduleClasses->subject_id) ? Subject::find($scheduleClasses->subject_id)->name : "";
        })
        ->addColumn('actions', function ($scheduleClasses) {
            return view('schedule_classes.action', ['scheduleClasses' => $scheduleClasses]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    public function index()
    {
        return view('schedule_classes.index');
    }

    public function create(Request $request)
    {
        $subjects = Subject::all();

        if(old('type_id') != null){
            if(old('type_id') == '1'){
                return view('schedule_classes.online.group',compact('subjects'));
            } elseif(old('type_id') == '2'){
                return view('schedule_classes.online.one_one',compact('subjects'));
            } elseif(old('type_id') == '3'){
                return view('schedule_classes.offline.group',compact('subjects'));
            } else {
                return view('schedule_classes.offline.one_one',compact('subjects'));
            }
        } else {
            if($request->online_group == 'on'){
                return view('schedule_classes.online.group',compact('subjects'));
            } elseif($request->online_one_one == 'on') {
                return view('schedule_classes.online.one_one',compact('subjects'));
            } elseif($request->offline_group == 'on') {
                return view('schedule_classes.offline.group',compact('subjects'));
            } else {
                return view('schedule_classes.offline.one_one',compact('subjects'));
            }
        }
    }

    public function getTopicBySubject(Request $request)
    {
        $topics = Topic::where('subject_id', $request->subject_id)->pluck('name', 'id')->toArray();
        return ['topics' => $topics];
    }

    public function store(Request $request)
    {
        // dd($request->all());
        // Type_id Explaination==> 1 = online-grp | 2 = online-1-1 | 3 = offline-grp | 4 = offline-1-1
        if($request->type_id == 1 || $request->type_id == 2){ //ONLINE
            $this->validate($request, [
                'name' => 'required',
                // 'date' => 'required',
                // 'centres' => 'required',
                // 'tutors' => 'required',
                'lesson' => 'required',
                'live_link' => 'required',
                // 'start_time' => 'required',
                // 'end_time' => 'required',
                'class_size' => 'required',
                'price' => 'required',
            ]);
        }else if($request->type_id == 3 || $request->type_id == 4){//OFFLINE
            $this->validate($request, [
                'name' => 'required',
                // 'date' => 'required',
                // 'centres' => 'required',
                // 'tutors' => 'required',
                'lesson' => 'required',
                // 'start_time' => 'required',
                // 'end_time' => 'required',
                'class_size' => 'required',
                'price' => 'required',
            ]);
        }

        $class = new ScheduleClass();
        if ($request->banner != '') {
            $image = $request->banner_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->banner;

            $path = public_path() . '/class_banners/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/class_banners/' . $imageName, base64_decode($image));

            $class->banner = $imageName;
        }
        // if($request->banner != ''){
        // if ($logo = $request->banner) {
        //     $logo_name = $request->first_name.$request->banner;
        //     $target_path = public_path('/class_banners/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $class->banner = $logo_name;
        //     }
        // }
        // }
        $class->type_id = $request->type_id;
        $class->name = $request->name;
        $class->street_name = $request->street_name;
        $class->city = $request->city;
        $class->zip_code = $request->zip_code;
        $class->latitude = $request->lat;
        $class->longitude = $request->long;
        $class->building_no = $request->building_no;
        if ($request->classType == 'reccur') {
            $class->duration = $request->duration_hrs;
            $class->start_time = date('H:i:s',strtotime($request->start_time));
            $class->end_time = date('H:i:s',strtotime($request->end_time));
            $class->class_date = date('Y-m-d',strtotime($request->date));
            $class->no_lesson = $request->no_lesson;
        }else{
            $class->is_special = 1;
        }

        $class->subject_id = $request->subject_id;
        $class->level_id = $request->level_id;
        $class->lesson_id = $request->lesson;
        $class->topic_id = $request->topic_id;
        $class->live_link = $request->live_link;
        $class->live_id = $request->live_id;
        $class->live_password = $request->live_password;
        $class->lms_link = $request->lms_link;
        $class->mas_link = $request->mas_link;
        $class->class_size = $request->class_size;
        $class->description = $request->description;
        $class->price = $request->price;
        $class->is_recurring = $request->is_recurring ? 1 : 0;
        $class->everyWeekday = $request->everyWeekday ? 1 : 0;
        $class->everyWeek = $request->everyWeek ? 1 : 0;
        $class->everyMonth = $request->everyMonth ? 1 : 0;
        $class->endRecurring_date = date('Y-m-d',strtotime($request->endRecurring_date));
        $class->created_by = Auth::user()->id;
        $class->save();

        if ($request->classType == 'special') {
            foreach ($request->special_class_days as $key => $classDetail) {
                $SpecialClassSchedule = new SpecialClassSchedule();
                $SpecialClassSchedule->class_id = $class->id;
                $SpecialClassSchedule->class_date = date('Y-m-d', strtotime($classDetail['class_date']));
                $SpecialClassSchedule->start_time = date('H:i:s',strtotime($classDetail['time_from']));
                $SpecialClassSchedule->end_time = date('H:i:s',strtotime($classDetail['time_to']));
                $SpecialClassSchedule->save();
            }
            $SpecialClassSchedule = SpecialClassSchedule::where('class_id', $class->id)->orderBy('class_date')->get()->last();
            $SpecialClassScheduleFirst = SpecialClassSchedule::where('class_id', $class->id)->orderBy('class_date')->first();
            $class_date_add = ScheduleClass::find($class->id);
            $class_date_add->start_time = date('H:i:s',strtotime($SpecialClassSchedule->start_time));
            $class_date_add->end_time = date('H:i:s',strtotime($SpecialClassSchedule->end_time));
            $class_date_add->class_date = date('Y-m-d',strtotime($SpecialClassScheduleFirst->class_date));
            $class_date_add->endRecurring_date = date('Y-m-d',strtotime($SpecialClassSchedule->class_date));
            $class_date_add->save();
        }else{
            $class_detail = ScheduleClass::find($class->id);
            $attendanceDate = [];
            for ($i=0; $i < $class_detail->no_lesson ; $i++) {
                $day = date('D', strtotime($class_detail->class_date));
                if ($i == 0) {
                    $attendanceDate[] = $class_detail->class_date;
                }else{
                    $attendanceDate[] = date('Y-m-d', strtotime($attendanceDate[$i - 1]. ' + 7 days'));
                }
                // dd(date('Y-m-d', strtotime($class_detail->class_date. ' + 7 days')));
            }
            $class_date_add = ScheduleClass::find($class->id);
            $class_date_add->endRecurring_date = $attendanceDate[$class_detail->no_lesson - 1];
            $class_date_add->save();

            for($i = 0;$i < count($request->no_lesson_value);$i++){
                $dateLesson = date('Y-m-d',strtotime($request->lesson_date[$i]));

                $RecurrClassSchedule = new RecurrClassSchedule();
                $RecurrClassSchedule->class_id = $class_date_add->id;
                $RecurrClassSchedule->lesson_no = $i + 1;
                $RecurrClassSchedule->lesson_date = $dateLesson;
                $RecurrClassSchedule->start_time = $request->lesson_start_time[$i];
                $RecurrClassSchedule->duration_hrs = $request->lesson_duration_hrs[$i];
                $RecurrClassSchedule->duration_min = $request->duration_mins[$i];
                $RecurrClassSchedule->end_time = $request->lesson_end_time[$i];
                $RecurrClassSchedule->save();
            }
        }

        $user = Auth::user();
        if($user->roles->first()->name == 'tutor' || $user->roles->first()->name == 'tuition center'){
            if($user->roles->first()->name == 'tutor'){
                $account = Account::where('user_id',$user->id)->first();
                $tutor1 = new Classtutorlink();
                $tutor1->class_id = $class->id;
                $tutor1->tutor_id = $account->id;
                $tutor1->save();
            }else{
                $account = TuitionCentre::where('user_id',$user->id)->first();

                $tutor_centre = new ClasstuitionCentrelink;
                $tutor_centre->class_id = $class->id;
                $tutor_centre->tuition_centre_id = $account->id;
                if($request->centre != ''){
                    $tutor_centre->center_id = $request->centre;
                }
                $tutor_centre->save();
            }
        }else{
            if ($request->tuition == 'tutor') {
                $tutor1 = new Classtutorlink();
                $tutor1->class_id = $class->id;
                $tutor1->tutor_id = $request->tutors;
                $tutor1->save();
            }elseif ($request->tuition == 'center') {
                $tutor_centre = new ClasstuitionCentrelink;
                 $tutor_centre->class_id = $class->id;
                 $arr = explode(",",$request->centres);
                 if($arr[0] == 'other'){
                    $tutor_centre->tuition_centre_id = $arr[2];
                    $tutor_centre->center_id = $arr[1];
                 }else{
                    $tutor_centre->tuition_centre_id = $request->centres;
                 }
                 $tutor_centre->save();
            }
        }
        return redirect()->route('class.index')->with('message', 'Class scheduled successfully');
    }

    public function storeAnother(Request $request)
    {
        dd($request->all());
        //Type_id Explaination==> 1 = online-grp | 2 = online-1-1 | 3 = offline-grp | 4 = offline-1-1
        if($request->type_id == 1){
            $this->validate($request, [
                'class_Name' => 'required',
                'subject_id' => 'required',
                'topic_id' => 'required',
                'zoom_link' => 'required',
                'zoom_id' => 'required',
                'zoom_password' => 'required',
                'start_time' => 'required',
                'end_time' => 'required',
                'class_size' => 'required',
                'price' => 'required',
                'selectedDate' => 'required',
            ]);
        }else{
            $this->validate($request, [
                'class_banner' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
                'name' => 'required',
                'type_id' => 'required', //1: online-grp | 2: online-1-1 | 3: offline-grp | 4:offline-1-1
                'day' => 'required',
                'start_time' => 'required',
                'end_time' => 'required',
                'price' => 'required',
                'subject_id' => 'required',
                'is_recurring' => 'required'
            ]);
        }


        $class = new ScheduleClass();
        if ($banner = $request->file('class_banner')) {
            $name = $request->file('class_banner')->getClientOriginalName();
            $target_path = public_path('/class_banners/');
            if ($banner->move($target_path, $name))
                $class->banner = $name;
        }
        $class->type_id = $request->type_id;
        $class->name = $request->name;
        $class->day = $request->day;
        $class->last_class_day = $request->last_class_day;
        $class->start_time = date('H:i:s',strtotime($request->start_time));
        $class->end_time = date('H:i:s',strtotime($request->end_time));
        $class->subject_id = $request->subject_id;
        $class->lesson_id = $request->lesson;
        $class->class_size = $request->class_size;
        $class->is_recurring = $request->is_recurring;
        $class->price = $request->price;
        $class->description = $request->description;
        $class->street_name = $request->street_name;
        $class->state = $request->state;
        $class->city = $request->city;
        $class->zip_code = $request->zip_code;
        $class->created_by = Auth::user()->id;
        $class->save();

        return redirect()->route('schedule-class.index')->with('message', 'Class scheduled successfully');

    }

    public function edit($id)
    {
        $class = ScheduleClass::find($id);
        $subjects = Subject::all();
        $topics = Topic::where('subject_id',$class->subject_id)->get();
        return view('classes.edit',compact('class','subjects','topics'));
        // if($class->type_id == '1')
        //     return view('schedule_classes.online.edit_group',compact('class','subjects','topics'));
        // elseif($class->type_id == '2')
        //     return view('schedule_classes.online.edit_one_one',compact('class','subjects','topics'));
        // elseif($class->type_id == '3')
        //     return view('schedule_classes.offline.edit_group',compact('class','subjects','topics'));
        // else
        //     return view('schedule_classes.offline.edit_one_one',compact('class','subjects','topics'));
    }

    public function update(Request $request, $id)
    {
        // dd($request->all());
        if($request->type_id == 1 || $request->type_id == 2){
            $this->validate($request, [
                'name' => 'required',
                // 'date' => 'required',
                /*'centres' => 'required',
                'tutors' => 'required',*/
                'lesson' => 'required',

                // 'street_name' => 'required',
                // 'city' => 'required',
                // 'zip_code' => 'required',
                // 'building_no' => 'required',

                // 'lms_link' => 'required',
                // 'mas_link' => 'required',

                'live_link' => 'required',
                /*'start_time' => 'required',
                'end_time' => 'required',*/
                'class_size' => 'required',
                'price' => 'required',
            ]);
        } else if ($request->type_id == 3 || $request->type_id == 4){
            $this->validate($request, [
                'name' => 'required',
                // 'date' => 'required',
                // 'centres' => 'required',
                // 'tutors' => 'required',
                'lesson' => 'required',
                // 'street_name' => 'required',
                // 'city' => 'required',
                // 'zip_code' => 'required',
                // 'building_no' => 'required',
                // 'lms_link' => 'required',
                // 'mas_link' => 'required',
                // 'start_time' => 'required',
                // 'end_time' => 'required',
                'class_size' => 'required',
                'price' => 'required',
            ]);
        }

        $class = ScheduleClass::find($id);

        if ($request->banner != '') {
        $image = $request->banner_url;  // your base64 encoded
        $image = str_replace('data:image/png;base64,', '', $image);
        $image = str_replace(' ', '+', $image);
        $imageName = $request->banner;

        $path = public_path() . '/class_banners/';
        File::exists($path) or File::makeDirectory($path, 0777, true);
        File::put(public_path() . '/class_banners/' . $imageName, base64_decode($image));

        $class->banner = $imageName;
        }

        // if($request->banner != ''){
        // if ($logo = $request->banner) {
        //     $logo_name = $request->first_name.$request->banner;
        //     $target_path = public_path('/class_banners/');
        //     // dd($logo_name);
        //     if ($logo->move($target_path, 'My project.png')) {
        //         $class->banner = $logo_name;
        //     }
        // }
        // }

        $class->type_id = $request->type_id;
        $class->name = $request->name;
        $class->street_name = $request->street_name;
        $class->city = $request->city;
        $class->zip_code = $request->zip_code;
        $class->building_no = $request->building_no;
        $class->subject_id = $request->subject_id;
        $class->lesson_id = $request->lesson;
        $class->level_id = $request->level_id;
        $class->topic_id = $request->topic_id;
        $class->live_link = $request->live_link;
        $class->live_id = $request->live_id;
        if ($request->classType == 'reccur') {
            $class->duration = $request->duration_hrs;
            $class->start_time = date('H:i:s',strtotime($request->start_time));
            $class->end_time = date('H:i:s',strtotime($request->end_time));
            $class->class_date = date('Y-m-d',strtotime($request->date));
            $class->no_lesson = $request->no_lesson;
        }else{
            $class->is_special = 1;
        }
        $class->live_password = $request->live_password;
        $class->lms_link = $request->lms_link;
        $class->mas_link = $request->mas_link;
        $class->class_size = $request->class_size;
        $class->description = $request->description;
        $class->latitude = $request->lat;
        $class->longitude = $request->long;
        $class->price = $request->price;
        $class->is_recurring = $request->is_recurring ? 1 : 0;
        $class->everyWeekday = $request->everyWeekday ? 1 : 0;
        $class->everyWeek = $request->everyWeek ? 1 : 0;
        $class->everyMonth = $request->everyMonth ? 1 : 0;
        // $class->endRecurring_date = date('Y-m-d',strtotime($request->endRecurring_date));
        $class->created_by = Auth::user()->id;
        $class->save();

        if ($request->classType == 'special') {
            $ClassStudent_delete = SpecialClassSchedule::where('class_id', $class->id)->delete();
            foreach ($request->special_class_days as $key => $classDetail) {
                $SpecialClassSchedule = new SpecialClassSchedule();
                $SpecialClassSchedule->class_id = $class->id;
                $SpecialClassSchedule->class_date = date('Y-m-d', strtotime($classDetail['class_date']));
                $SpecialClassSchedule->start_time = date('H:i:s',strtotime($classDetail['time_from']));
                $SpecialClassSchedule->end_time = date('H:i:s',strtotime($classDetail['time_to']));
                $SpecialClassSchedule->save();
            }

            $SpecialClassSchedule = SpecialClassSchedule::where('class_id', $class->id)->orderBy('class_date')->get()->last();
            $SpecialClassScheduleFirst = SpecialClassSchedule::where('class_id', $class->id)->orderBy('class_date')->first();
            $class_date_add = ScheduleClass::find($class->id);
            $class_date_add->start_time = date('H:i:s',strtotime($SpecialClassSchedule->start_time));
            $class_date_add->end_time = date('H:i:s',strtotime($SpecialClassSchedule->end_time));
            $class_date_add->class_date = date('Y-m-d',strtotime($SpecialClassScheduleFirst->class_date));
            $class_date_add->endRecurring_date = date('Y-m-d',strtotime($SpecialClassSchedule->class_date));
            $class_date_add->save();
        }else{
            $class_detail = ScheduleClass::find($class->id);
            $attendanceDate = [];
            for ($i=0; $i < $class_detail->no_lesson ; $i++) {
                $day = date('D', strtotime($class_detail->class_date));
                if ($i == 0) {
                    $attendanceDate[] = $class_detail->class_date;
                }else{
                    $attendanceDate[] = date('Y-m-d', strtotime($attendanceDate[$i - 1]. ' + 7 days'));
                }
                // dd(date('Y-m-d', strtotime($class_detail->class_date. ' + 7 days')));
            }
            $class_date_add = ScheduleClass::find($class->id);
            $class_date_add->endRecurring_date = $attendanceDate[$class_detail->no_lesson - 1];
            $class_date_add->save();

            for($i = 0;$i < count($request->no_lesson_value);$i++){
                $dateLesson = date('Y-m-d',strtotime($request->lesson_date[$i]));

                $RecurrClassSchedule = RecurrClassSchedule::where('class_id', $class->id)->where('lesson_no', $i + 1)->first();
                $RecurrClassSchedule->class_id = $class->id;
                $RecurrClassSchedule->lesson_no = $i + 1;
                $RecurrClassSchedule->lesson_date = $dateLesson;
                $RecurrClassSchedule->start_time = $request->lesson_start_time[$i];
                $RecurrClassSchedule->duration_hrs = $request->lesson_duration_hrs[$i];
                $RecurrClassSchedule->duration_min = $request->duration_mins[$i];
                $RecurrClassSchedule->end_time = $request->lesson_end_time[$i];
                $RecurrClassSchedule->save();
            }
        }

        $user = Auth::user();
        if($user->roles->first()->name != 'tutor' && $user->roles->first()->name != 'tuition center'){
            $delete_tutor = Classtutorlink::where('class_id',$id)->delete();
            $delete_tutor_centres = ClasstuitionCentrelink::where('class_id',$id)->delete();
            if ($request->tuition == 'tutor') {
                $tutor1 = new Classtutorlink();
                $tutor1->class_id = $class->id;
                $tutor1->tutor_id = $request->tutors;
                $tutor1->save();
            }
            if ($request->tuition == 'center') {
                 $tutor_centre = new ClasstuitionCentrelink();
                 $tutor_centre->class_id = $class->id;
                 $arr = explode(",",$request->centres);
                 if($arr[0] == 'other'){
                    $tutor_centre->tuition_centre_id = $arr[2];
                    $tutor_centre->center_id = $arr[1];
                 }else{
                    $tutor_centre->tuition_centre_id = $request->centres;
                 }
                 $tutor_centre->save();
            }
        }else{
            if($user->roles->first()->name == 'tuition center'){
                $acc = TuitionCentre::where('user_id',auth()->user()->id)->first();
                $update = ClasstuitionCentrelink::where('tuition_centre_id',$acc->id)->where('class_id',$class->id)->first();
                if($request->centre != ''){
                    $update->center_id = $request->centre;
                 }else{
                    $update->center_id = null;
                 }
                $update->save();
            }
        }
        return redirect()->route('class.index')->with('message', 'Class updated successfully');
    }

    public function destroy($id)
    {
        $class = ScheduleClass::find($id);
        $class->delete();

        return redirect()->route('class.index')->with('message', 'Class deleted successfully');
    }

    public function getClassDetails($class_id)
    {
        $class = ScheduleClass::find($class_id);
        $lesson = Lessons::where('id',$class->lesson_id)->first();
        $subject = $lesson ? (Subject::find($lesson->subject_id) ? Subject::find($lesson->subject_id)->name : "-") : '';
        $class->subject_id = $subject;
        $class->topic_id = $lesson ? (Topic::find($lesson->topic_id) ? Topic::find($lesson->topic_id)->name : "-") : '';
        $class->live_link = $class->live_link ? $class->live_link : "";
        $class->live_id = $class->live_id ? $class->live_id : "";
        $class->live_password = $class->live_password ? $class->live_password : "";
        $class->edit_url = route('class.edit', $class->id);

        return $class;
    }

    public function dragDropDateUpdate($class_id, $new_date)
    {
        $class = ScheduleClass::find($class_id);
        $class->class_date = $new_date;
        $class->save();

        return true;
    }

    public function getScheduledClasses()
    {
        $index = 0;
            $grp_id = 0;
            $scheduleClasses = ScheduleClass::orderBy('id','DESC')->get();
            $final_array = array(array());
            $loc_arr = array();

            foreach($scheduleClasses as $class){
                $start_day = date('D',strtotime($class->class_date));
                $is_weekday = $start_day == 'Sat' || $start_day == 'Sun' ? '0' : '1';
                if($class->is_recurring){
                    if($class->everyWeekday){
                        $interval = DateInterval::createFromDateString('1 day');
                        $period = new DatePeriod(new DateTime($class->class_date), $interval, new DateTime($class->endRecurring_date.' +1 day'));

                        foreach ($period as $dt) {
                            if($is_weekday){
                                if(!($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun')){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d')
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            } else {
                                if($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun'){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d')
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            }
                        }
                    } else if($class->everyWeek){
                        $interval = DateInterval::createFromDateString('1 week');
                        $period = new DatePeriod(new DateTime($class->class_date), $interval, new DateTime($class->endRecurring_date.' +1 day'));

                        foreach ($period as $dt) {
                            $loc_arr = array(
                                'grp' => $grp_id,
                                'id' => $class->id,
                                'name' => $class->name,
                                'class_date' => $dt->format('Y-m-d')
                            );
                            $final_array[$index++] = $loc_arr;
                        }
                    } else { //MONTHLY
                        $interval = DateInterval::createFromDateString('1 month');
                        $period = new DatePeriod(new DateTime($class->class_date), $interval, new DateTime($class->endRecurring_date.' +1 day'));

                        foreach ($period as $dt) {
                            if($is_weekday){
                                if(!($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun')){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d')
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            } else {
                                if($dt->format('D') == 'Sat' || $dt->format('D') == 'Sun'){
                                    $loc_arr = array(
                                        'grp' => $grp_id,
                                        'id' => $class->id,
                                        'name' => $class->name,
                                        'class_date' => $dt->format('Y-m-d')
                                    );
                                    $final_array[$index++] = $loc_arr;
                                }
                            }
                        }
                    }
                } else {
                    $loc_arr = array(
                        'grp' => $grp_id,
                        'id' => $class->id,
                        'name' => $class->name,
                        'class_date' => $class->class_date
                    );
                    $final_array[$index++] = $loc_arr;
                }
                $grp_id++;
            }

        return $final_array;
    }

    public function ChangeSponcerClass(Request $request, $class)
    {
        $count_spo = ScheduleClass::where('is_sponsored', '1')->get()->count();
        // $position = $count_spo;

        $class = ScheduleClass::find($class);
        $class->is_sponsored = '1';
        $class->position = $count_spo;
        $class->save();
        return redirect()->route('class.index')->with('message', 'Class successfully Added into sponsored class');
    }

    public function ChangeNormalClass(Request $request, $class)
    {
        // dd($class);

        $class = ScheduleClass::find($class);
        $class->is_sponsored = '0';
        $class->position = NULL;
        $class->save();
        return redirect()->route('class.index')->with('message', 'Class successfully Added into normal class');
    }

    public function reorderRows(Request $request)
    {
        // dd($request->all());
        $newOrder = $request->input('order');
        // dd($newOrder);
        foreach ($newOrder as $order => $itemId) {
            ScheduleClass::where('id', $itemId)->update(['position' => $order]);
        }

        return response()->json(['message' => 'Rows reordered successfully']);
    }
}
