<?php

namespace App\Http\Controllers;

use App\Models\Lessons;
use App\Models\Levels;
use App\Models\Subject;
use App\Models\Topic;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class SubjectController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-subject')->only('index', 'getData');
        $this->middleware('permission:create-subject')->only('create', 'store');
        $this->middleware('permission:edit-subject')->only('edit', 'update');
        $this->middleware('permission:delete-subject')->only('destroy');
    }

    public function index()
    {
        $levels = Levels::all();
        return view('subjects.index', compact('levels'));
    }

    public function cancel($tab)
    {
        return redirect()->route('subject.index');
    }

    public function getTopic(Request $request)
    {
        $subject = [];
        $topic = [];
        if($request->type == 'subject'){
         $subject = Subject::where('level_id',$request->level)->whereNotNull('level_id')->get();
        }elseif($request->type == 'lesson'){
            $topic = Lessons::where('topic_id',$request->topic)->whereNotNull('topic_id')->get();
        }else{
            $topic = Topic::where('subject_id',$request->subject)->whereNotNull('subject_id')->get();
        }

        return [ 'topics' => $topic , 'subjects' => $subject ];
    }

    public function getData(Request $request)
    {
        // dd($request->all());
        $subjects = Subject::orderBy('updated_at','desc');

        if ($request->level != '') {
            $subjects->where('level_id', $request->level);
        }

        $subjects->get();

        return DataTables::of($subjects)
        ->addColumn('level_id', function ($subjects) {
            return Levels::find($subjects->level_id) ? Levels::find($subjects->level_id)->name : '';
        })
        ->editColumn('created_at', function ($subjects) {
            return date('d-m-Y', strtotime($subjects->created_at));
        })
        ->addColumn('updated_at', function ($admin) {
            return date('Y-m-d', strtotime($admin->updated_at));
        })
        ->addColumn('actions', function ($subjects) {
            return view('subjects.action', ['subjects' => $subjects]);
        })
        ->rawColumns(['actions'])->make(true);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $levels = Levels::all();
        return view('subjects.create',compact('levels'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'level' => 'required',
            'name' => 'required',
        ], [
            'name.required' => 'Name of subject is required.',
            'level.required' => 'Please Select Level.'
        ]);
        $find = Subject::where('level_id', $request->level)->where('name',$request->name)->first();
        if($find != ''){
        return redirect()->back()->withErrors('Subject Already Exist On This Level!')->withInput();
        }
        $subject = new Subject ;
        $subject->name = $request->name;
        $subject->level_id = $request->level;
        $subject->save();
        return redirect()->route('subject.index')->with('message', 'Subject created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Subject  $subject
     * @return \Illuminate\Http\Response
     */
    public function show(Subject $subject)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Subject  $subject
     * @return \Illuminate\Http\Response
     */
    public function edit(Subject $subject)
    {
        $levels = Levels::all();
        return view('subjects.edit',compact('subject','levels'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Subject  $subject
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Subject $subject)
    {
        $this->validate($request, [
            'level' => 'required',
            'name' => 'required',
        ], [
            'name.required' => 'Name of subject is required.',
            'level.required' => 'Please Select Level.'
        ]);
        $find = Subject::where('level_id', $request->level)->where('name',$request->name)->where('id','!=',$subject->id)->first();
        if($find != ''){
        return redirect()->back()->withErrors('Subject Already Exist On This Level!')->withInput();
        }
        $subjectUpdate = $subject ;
        $subjectUpdate->name = $request->name;
        $subjectUpdate->level_id = $request->level;
        $subjectUpdate->save();
        return redirect()->route('subject.index')->with('message', 'Subject Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Subject  $subject
     * @return \Illuminate\Http\Response
     */
    public function destroy(Subject $subject)
    {
        $subject->delete() ;
        return redirect()->route('subject.index')->with('message', 'Subject Deleted successfully');
    }
}
