<?php

namespace App\Http\Controllers;

use Auth;
use DataTables;
use App\Models\Tutor;
use App\Models\User;
use App\Models\TuitionCentre;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Mail\TuitionCenter;
use Illuminate\Support\Facades\Mail;
use File;
class TuitionCentreController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-tuition-centre')->only('index', 'data');
        $this->middleware('permission:create-tuition-centre')->only('create', 'store');
        $this->middleware('permission:edit-tuition-centre')->only('edit', 'update');
        $this->middleware('permission:delete-tuition-centre')->only('destroy');
        $this->middleware('permission:show-details-tuition-centre')->only('show');
    }

    public function data(Request $request)
    {
        // dd($request->all());
        $tuitionCentres = TuitionCentre::orderBy('updated_at','desc');

        if($request->status != ''){
            $tuitionCentres->where('is_verified',$request->status);
        }

        $tuitionCentres->get();

        return DataTables::of($tuitionCentres)
            ->editColumn('fee_structure', function ($tuitionCentre) {
                return "str";
            })
            ->editColumn('fee_amount', function ($tuitionCentre) {
                return "amount";
            })
            ->editColumn('created_at', function ($tuitionCentre) {
                return date('d-m-Y', strtotime($tuitionCentre->created_at));
            })
            ->editColumn('updated_at', function ($tuitionCentre) {
                return date('Y-m-d', strtotime($tuitionCentre->updated_at));
            })
            ->editColumn('email', function ($tuitionCentre) {
                $user = User::find($tuitionCentre->user_id);
                return $user->email;
            })
            ->editColumn('status', function ($tuitionCentre) {
                if($tuitionCentre->is_verified == 0){
                    return '<a class="btn btn-warning" onclick="return confirm(\'Are you sure want to change status as Verified ?\');" style="border:none;color:#ce7906;background:#ed921847;" href="'.route('tuition-centre.changestatus',['id' => $tuitionCentre->id,'value' => 1]).'">Unverified</a>';
                }else{
                    return '<a class="btn btn-success" onclick="return alert(\'Can not change status after once you Verified\');" style="border:none;color:#26ab38;background:#26ab3863;cursor:default;" >Verified</a>';
                }
            })
            ->addColumn('actions', function ($tuitionCentre) {
                return view('tuition_centers.action', ['tuitionCentre' => $tuitionCentre]);
            })
            // ->escapeColumns('actions')
            ->rawColumns(['actions','status'])->make(true);
    }

    public function ChangeStatus(Request $request){
        $store = TuitionCentre::find($request->id);
        $store->is_verified = $request->value;
        $store->save();
        $status = $request->value == 0 ? 'Unverified' : 'Verified';
        return redirect()->route('tuition-centre.index')->with('message','Tuition Centre '.$status.' Successfully.');
    }

    public function index()
    {
       return view('tuition_centers.index');
    }

    public function create()
    {
        $edit = 0;
        $contact_number = 65;
        $cp_contact_number = 65;
        return view('tuition_centers.create',compact('edit','contact_number','cp_contact_number'));
    }

    public function store(Request $request)
    {
        // dd($request);
        $user = Auth::user();
        // dd($user->id);
        // dd($user->roles->first()->name);
        $this->validate($request, [
            // 'logo_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'name' => 'required|min:3|max:50|unique:tuition_centres,name,NULL,id',
            'uen' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email,NULL,id',
            'contact_number' => 'required',
            'contact_person_name' => 'required',
            'contact_person_email' => 'required',
            'contact_person_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:6',
        ]);
        $centre = new TuitionCentre();

        if ($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/logo_images/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/logo_images/' . $imageName, base64_decode($image));

            $centre->logo_name = $imageName;
            }

        // if ($logo = $request->file('logo_image')) {
        //     $logo_name = $request->file('logo_image')->getClientOriginalName();

        //     $target_path = public_path('/logo_images/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $centre->logo_name = $logo_name;
        //     }
        // }

        $this_user = User::create([
            'name' => $request->contact_person_name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);

        $this_user->assignRole('tuition center');

        $centre->user_id = $this_user->id;
        $centre->name = $request->name;
        $centre->uen = $request->uen;
        $centre->street_name = $request->street_name;
        $centre->state = $request->state;
        $centre->city = $request->city;
        $centre->zip_code = $request->zip_code;
        $centre->email = $request->email;
        $centre->contact_number = $request->countryCode.$request->contact_number;
        $centre->website = $request->website;
        $centre->contact_person_name = $request->contact_person_name;
        $centre->contact_person_email = $request->contact_person_email;
        $centre->contact_person_number = $request->countryCode1.$request->contact_person_number;
        $centre->created_by = $user->id;
        $centre->remarks = $request->remarks;
        $centre->description = $request->description;
        $centre->save();

        $title = "Create new tuition center";
        $msg = $request->name.' tuition center created';

        Mail::to($request->email)->send(new TuitionCenter($title, $msg));

        return redirect()->route('tuition-centre.index')->with('message', 'Tuition Centre created successfully');
    }

    public function show(Request $request,$id)
    {
        if($request->show){
          $show = $request->show;
        }else{
          $show = '';
        }
        $tuitionCentre = TuitionCentre::where('user_id',$id)->first();
        $role = 'tuition center';
        $edit_route = route('tuition-centre.edit', $tuitionCentre->id);
        $previous = route('tuition-centre.index');
        $value = TuitionCentre::where('user_id',$id)->first();
        return view('tuition_centers.show',compact('value','show','role','previous','edit_route'));
    }

    public function edit(Request $request,$id)
    {
        $tuitionCentre = TuitionCentre::find($id);
        $edit = 1;
        if($request->from_profile){
            $previous = route('tuition-centre.show',$tuitionCentre->user_id);
            $from_profile = 1;
        }else{
            $previous = route('tuition-centre.index');
            $from_profile = 0;
        }
        $contact_number = substr($tuitionCentre->contact_number, 0, -10) == '' ? 65 : substr($tuitionCentre->contact_number, 0, -10);
        $cp_contact_number = substr($tuitionCentre->contact_person_number, 0, -10) == '' ? 65 : substr($tuitionCentre->contact_person_number, 0, -10);
        return view('tuition_centers.edit',compact('tuitionCentre','edit','previous','from_profile','cp_contact_number','contact_number'));
    }

    public function update(Request $request, $id)
    {
        $centre = TuitionCentre::find($id);
        $this->validate($request, [
            'name' => 'required|min:3|max:50|unique:tuition_centres,name,'.$id,
            'uen' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email,'.$centre->user_id,
            'contact_number' => 'required',
            'contact_person_name' => 'required',
            'contact_person_email' => 'required',
            'contact_person_number' => 'required',
        ]);
        $centre = TuitionCentre::find($id);
        $user = User::find($centre->user_id);


        if ($request->logo_image != '') {
            $image = $request->logo_image_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->logo_image;

            $path = public_path() . '/logo_images/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/logo_images/' . $imageName, base64_decode($image));

            $centre->logo_name = $imageName;
            }
        // if ($logo = $request->file('logo_image')) {
        //     $logo_name = $request->name.$request->file('logo_image')->getClientOriginalName();

        //     $target_path = public_path('/logo_images/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $centre->logo_name = $logo_name;
        //     }
        // }

        $centre->name = $request->name;
        $centre->uen = $request->uen;
        $centre->street_name = $request->street_name;
        $centre->state = $request->state;
        $centre->city = $request->city;
        $centre->zip_code = $request->zip_code;
        $centre->email = $request->email;
        $centre->contact_number = $request->countryCode.$request->contact_number;
        $centre->website = $request->website;
        $centre->contact_person_name = $request->contact_person_name;
        $centre->contact_person_email = $request->contact_person_email;
        $centre->contact_person_number = $request->countryCode1.$request->contact_person_number;
        $centre->remarks = $request->remarks;
        $centre->description = $request->description;
        $centre->created_by = Auth::user()->id;
        if($request->password != ""){
            if($request->password != $request->password_confirmation){
                return redirect()->back()->withErrors(["Confirm Password didn't match"])->withInput();
            } else {
                User::where('id', $centre->user_id)->update([
                    'name' => $request->contact_person_name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password)
                ]);
            }
        } else {
            $user = User::where('id', $centre->user_id)->update([
                'name' => $request->contact_person_name,
                'email' => $request->email,
            ]);
        }
        $centre->save();
        if($request->from_profile == 1){
            return redirect()->route('tuition-centre.show',$centre->user_id)->with('message', 'Tuition Centre updated successfully');
        }else{
            return redirect()->route('tuition-centre.index')->with('message', 'Tuition Centre updated successfully');
        }
    }

    public function destroy($id)
    {
        $centre = TuitionCentre::find($id);
        User::find($centre->user_id)->delete();
        $centre->delete();
        return redirect()->route('tuition-centre.index')->with('message', 'Tuition Centre deleted successfully');
    }
}
