<?php

namespace App\Http\Controllers;

use App\Models\TuitionCentre;
use App\Models\Tutor;
use App\Models\User;
use Auth;
use DataTables;
// use Mail;
use DB;
use File;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
// use App\Mail\AdminNotificationForTutorCreation;
use App\Models\Account;
use App\Models\ScheduleClass;
use App\Models\Classtutorlink;
use App\Models\Subject;
use App\Mail\TutorMail;
use App\Models\ClasstuitionCentrelink;
use App\Models\Lessons;
use App\Models\StudentClass;
use Illuminate\Support\Facades\Mail;

class TutorController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('permission:view-tutor')->only('index', 'data');
        $this->middleware('permission:view-student')->only('student_dashboard');
        $this->middleware('permission:delete-tutor')->only('destroy');
        $this->middleware('permission:show-details-tutor')->only('show');
    }

    public function data(Request $request)
    {
        $user = User::role('tutor')->pluck('id')->toArray();
        $tutors = Account::whereIn('user_id', $user);

        if($request->status != ''){
            $tutors->where('is_verify',$request->status);
        }

        $tutors->orderBy('updated_at','desc')->get();

        return DataTables::of($tutors)
            ->addColumn('name', function ($tutor) {
                return $tutor->first_name . " " . $tutor->last_name;
            })
            ->editColumn('fee_structure', function ($tutor) {
                return "str";
            })
            ->editColumn('fee_amount', function ($tutor) {
                return "amount";
            })
            ->editColumn('created_at', function ($tutor) {
                return date('d-m-Y', strtotime($tutor->created_at));
            })
            ->editColumn('updated_at', function ($tutor) {
                return date('Y-m-d', strtotime($tutor->updated_at));
            })
            ->editColumn('email', function ($tutor) {
                $user = User::find($tutor->user_id);
                return $user->email;
            })
            ->editColumn('ratings', function ($tutor) {
                $rate = '<span>
                            <i class="fas fa-star"></i>
                            <i class="fas fa-star"></i>
                            <i class="fas fa-star"></i>
                            <i class="fas fa-star"></i>
                        </span>';
                return $rate;
            })
            ->editColumn('status', function ($tutor) {
                if($tutor->is_verify == 0){
                    return '<a class="btn btn-warning" onclick="return confirm(\'Are you sure want to change status as Verified ?\');" style="border:none;color:#ce7906;background:#ed921847;" href="'.route('tutor.changestatus',['id' => $tutor->id,'value' => 1]).'">Unverified</a>';
                }else{
                    return '<a class="btn btn-success" onclick="return alert(\'Can not change status after once you Verified\');" style="border:none;color:#26ab38;background:#26ab3863;cursor:default;" >Verified</a>';
                }
            })
            ->addColumn('actions', function ($tutor) {
                return view('tutors.action', ['tutor' => $tutor]);
            })
            ->escapeColumns('ratings')
        // ->escapeColumns('actions')
            ->rawColumns(['actions','status'])->make(true);
    }

    public function ChangeStatus(Request $request){
        // dd($request->all());
        $store = Account::find($request->id);
        $store->is_verify = $request->value;
        $store->save();
        $status = $request->value == 0 ? 'Unverified' : 'Verified';
        return redirect()->route('tutor.index')->with('message','Tutor '.$status.' Successfully.');
    }

    public function CompletedClassData(Request $request)
    {
        $tutors = Account::where('user_id', auth::user()->id)->first();
        $centre = TuitionCentre::where('user_id', Auth::user()->id)->first();
        if($tutors){
            $tutor_ids = Classtutorlink::where('tutor_id', $tutors->id)->pluck('class_id')->toArray();
        }else{
            if($request->center != ''){
                if($request->center == 'current'){
                    $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->whereNull('center_id')->pluck('class_id')->toArray();
                }else{
                    $tutor_ids = ClasstuitionCentrelink::where('center_id', $request->center)->pluck('class_id')->toArray();
                }
            }else{
                $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->pluck('class_id')->toArray();
            }
            // $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->pluck('class_id')->toArray();
        }

        $completed_class1 = ScheduleClass::whereIn('id', $tutor_ids)->where('endRecurring_date','=',date('Y-m-d'))->where('end_time','<',date('H:i:s'))->pluck('id')->toArray();
        $completed_class2 = ScheduleClass::whereIn('id', $tutor_ids)->where('endRecurring_date','<',date('Y-m-d'))->pluck('id')->toArray();
        $completed = array_merge($completed_class1,$completed_class2);

        $classes = ScheduleClass::whereIn('id',$completed)->orderBy('updated_at','desc')->get();
        // $scheduleClasses = [];
        // foreach ($classes as $key => $value) {
        //     if ($value->class_date < date('Y-m-d')) {
        //         $scheduleClasses[] = $value;
        //     }
        // }

        return DataTables::of($classes)
        ->editColumn('type_id', function ($scheduleClasses) {
            if($scheduleClasses->type_id == "1"){
                return 'Online Group Class' ;
            }else if($scheduleClasses->type_id == "2"){
                return 'Online 1 -1 Class' ;
            }else if($scheduleClasses->type_id == "3"){
                return 'Offline Group Class' ;
            }else if($scheduleClasses->type_id == "4"){
                return 'Offline 1 -1 Class' ;
            }else{
                return 'Trial classes' ;
            }
        })
        // ->editColumn('class_date', function ($scheduleClasses) {
        //     if($scheduleClasses->class_date == "" || $scheduleClasses->class_date == null){
        //         return date('d-m-Y', strtotime($scheduleClasses->created_at));
        //     }else{
        //         return date('d-m-Y', strtotime($scheduleClasses->class_date));
        //     }
        // })
        ->editColumn('class_date', function ($class) {
            return date('d-m-Y', strtotime($class->class_date)).' To '. date('d-m-Y', strtotime($class->endRecurring_date));
        })
        ->editColumn('created_at', function ($class) {
            return date('d-m-Y', strtotime($class->created_at));
        })
        ->addColumn('updated_at', function ($class) {
            return date('Y-m-d', strtotime($class->updated_at));
        })
        ->addColumn('class_time', function ($scheduleClasses) {
            return date('h:i A', strtotime($scheduleClasses->start_time)) . ' - ' . date('h:i A', strtotime($scheduleClasses->end_time)) ;
        })
        ->addColumn('actions', function ($scheduleClasses) {
            return view('schedule_classes.action', ['scheduleClasses' => $scheduleClasses]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    public function UpcomingClassData(Request $request)
    {
        // dd($request->center);
        $centre = TuitionCentre::where('user_id', Auth::user()->id)->first();
        $tutors = Account::where('user_id', auth::user()->id)->first();
        if($tutors){
            $tutor_ids = Classtutorlink::where('tutor_id', $tutors->id)->pluck('class_id')->toArray();
        }else{
            if($request->center != ''){
                if($request->center == 'current'){
                    $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->whereNull('center_id')->pluck('class_id')->toArray();
                }else{
                    $tutor_ids = ClasstuitionCentrelink::where('center_id', $request->center)->pluck('class_id')->toArray();
                }
            }else{
                $tutor_ids = ClasstuitionCentrelink::where('tuition_centre_id', $centre->id)->pluck('class_id')->toArray();
            }
        }
        $upcoming_class1 = ScheduleClass::whereIn('id', $tutor_ids)->where('endRecurring_date','=',date('Y-m-d'))->where('start_time','>=',date('H:i:s'))->pluck('id')->toArray();
        $upcoming_class2 = ScheduleClass::whereIn('id', $tutor_ids)->where('endRecurring_date','>',date('Y-m-d'))->pluck('id')->toArray();
        $upcoming = array_merge($upcoming_class1,$upcoming_class2);

        $classes = ScheduleClass::whereIn('id',$upcoming)->orderBy('updated_at','desc')->get();
        // $classes = ScheduleClass::whereIn('id', $tutor_ids)->orderBy('id','DESC')->get();
        // $scheduleClasses = [];
        // foreach ($classes as $key => $value) {
        //     if ($value->class_date >= date('Y-m-d')) {
        //         $scheduleClasses[] = $value;
        //     }
        // }

        return DataTables::of($classes)
        ->editColumn('type_id', function ($scheduleClasses) {
            if($scheduleClasses->type_id == "1"){
                return 'Online Group Class' ;
            }else if($scheduleClasses->type_id == "2"){
                return 'Online 1 -1 Class' ;
            }else if($scheduleClasses->type_id == "3"){
                return 'Offline Group Class' ;
            }else if($scheduleClasses->type_id == "4"){
                return 'Offline 1 -1 Class' ;
            }else{
                return 'Trial classes' ;
            }
        })
        // ->editColumn('class_date', function ($scheduleClasses) {
        //     if($scheduleClasses->class_date == "" || $scheduleClasses->class_date == null){
        //         return date('d-m-Y', strtotime($scheduleClasses->created_at));
        //     }else{
        //         return date('d-m-Y', strtotime($scheduleClasses->class_date));
        //     }
        // })
        ->editColumn('class_date', function ($class) {
            return date('d-m-Y', strtotime($class->class_date)).' To '. date('d-m-Y', strtotime($class->endRecurring_date));
        })
        ->editColumn('created_at', function ($class) {
            return date('d-m-Y', strtotime($class->created_at));
        })
        ->addColumn('updated_at', function ($class) {
            return date('Y-m-d', strtotime($class->updated_at));
        })
        ->addColumn('class_time', function ($scheduleClasses) {
            return date('h:i A', strtotime($scheduleClasses->start_time)) . ' - ' . date('h:i A', strtotime($scheduleClasses->end_time)) ;
        })
        ->editColumn('subject_id', function ($scheduleClasses) {
           $lesson = Lessons::find($scheduleClasses->lesson_id);
           return Subject::find($lesson->subject_id) ? Subject::find($lesson->subject_id)->name : "";
        })
        ->addColumn('actions', function ($scheduleClasses) {
            return view('schedule_classes.action', ['scheduleClasses' => $scheduleClasses]);
        })
        ->rawColumns(['actions'])->make(true);
    }

    public function index()
    {
        return view('tutors.admin_index');
    }

    public function create(Request $request)
    {
        $edit = 0;
        if($request->show){
            $show = 1;
        }else{
            $show = 0;
        }
        $contact_number = 65;
        return view('tutors.create',compact('edit','show','contact_number'));
    }

    public function student_dashboard(){
        $user = Auth::user();
        if(auth()->user()->roles->first()->name == 'tuition center'){
            $user_id = TuitionCentre::where('user_id',$user->id)->first();
            $std1 = ClasstuitionCentrelink::where('tuition_centre_id', $user_id->id)->pluck('class_id')->toArray();
            $status = $user_id->is_verified == 0 ? 'unverified' : 'verified';
         }else{
            $user_id = Account::where('user_id',$user->id)->first();
            $std1 = Classtutorlink::where('tutor_id', $user_id->id)->pluck('class_id')->toArray();
            $status = $user_id->is_verify == 0 ? 'unverified' : 'verified';
         }
        // $std = StudentClass::whereIn('class_id', $std1)->pluck('student_id')->toArray();
        // if($status == 'unverified'){
        //     $std1 = [];
        // }
        $enquired = StudentClass::where('student_status','0')->where('status','active')->whereIn('class_id',$std1)->orderBy('updated_at','desc')->get()->count();
        $enrolled = StudentClass::where('student_status','1')->where('status','active')->whereIn('class_id',$std1)->orderBy('updated_at','desc')->get()->count();
        // $enquired = StudentClass::where('student_status','0')->where('status','active')->whereIn('student_id',$std)->orderBy('updated_at','desc')->get()->count();
        // $enrolled = StudentClass::where('student_status','1')->where('status','active')->whereIn('student_id',$std)->orderBy('updated_at','desc')->get()->count();
        return view('students.tutor_student',compact('enquired','enrolled'));
    }

    public function store(Request $request)
    {
        // dd($request->all());
        $this->validate($request, [
            // 'profile_picture' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'email' => 'required|email|unique:accounts,email',
            'contact_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:8',
        ]);

        $user = User::create([
            'name' => $request->first_name . " " . $request->last_name,
            'email' => $request['email'],
            'password' => Hash::make($request['password']),
        ]);

        $user->assignRole('tutor');
        $tutor = new Account();

        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

             $tutor->profile_picture = $imageName;
        }

        if ($request->upload_document != '') {
                $image = $request->upload_document_url;  // your base64 encoded
                $image = str_replace('data:image/png;base64,', '', $image);
                $image = str_replace(' ', '+', $image);
                $imageName = $request->upload_document;

                $path = public_path() . '/upload_documents/';
                File::exists($path) or File::makeDirectory($path, 0777, true);
                File::put(public_path() . '/upload_documents/' . $imageName, base64_decode($image));

                 $tutor->upload_document = $imageName;
        }
        // if ($logo = $request->file('profile_picture')) {
        //     $logo_name = $request->first_name . $request->file('profile_picture')->getClientOriginalName();
        //     $target_path = public_path('/profile_pictures/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $tutor->profile_picture = $logo_name;
        //     }
        // }
        // if ($logo = $request->file('upload_document')) {
        //     $logo_name = $request->first_name . $request->file('upload_document')->getClientOriginalName();
        //     $target_path = public_path('/upload_documents/');

        //     if ($logo->move($target_path, $logo_name)) {
        //         $tutor->upload_document = $logo_name;
        //     }
        // }

        $tutor->user_id = $user->id;
        $tutor->first_name = $request->first_name;
        $tutor->last_name = $request->last_name;
        $tutor->email = $request->email;
        $tutor->tutor_type_id = $request->tutor_type_id; // 1- fulltime | 2 - parttime
        $tutor->breif_note = $request->breif_note;
        $tutor->contact_number = $request->countryCode.$request->contact_number;
        $tutor->remarks = $request->remarks;
        $tutor->password = Hash::make($request->password);
        $tutor->created_by = $user->id;
        $tutor->street_name = $request->street_name;
        $tutor->state = $request->state;
        $tutor->city = $request->city;
        $tutor->zip_code = $request->zip_code;
        $tutor->work_experience = $request->work_experience;
        $tutor->save();
        if ($request->subjects) {
            foreach ($request->subjects as $sub) {
                $data = array(
                    'tutor_id' => $tutor->id,
                    'subject_id' => $sub,
                    'created_at' => date('Y-m-d'),
                );
                DB::table('tutor_subjects')->insert($data);
            }
        }

        if($request->special_class_days){
            foreach ($request->special_class_days as $key => $value) {
                if ($value['institute_name1'] != null && $value['course_name1'] != null) {
                    $data = array(
                        'tutor_id' => $tutor->id,
                        'institute_name' => $value['institute_name1'],
                        'course_name' => $value['course_name1'],
                        'start_date' => $value['start_date_e'] != null  ? date('Y-m-d',strtotime($value['start_date_e'])) : null,
                        'end_date' => $value['end_date_e'] != null  ? date('Y-m-d',strtotime($value['end_date_e'])) : null,
                        'created_at' => date('Y-m-d'),
                    );
                    DB::table('tutor_educations')->insert($data);
                }
            }
        }

        if($request->working_expepierances){
            foreach ($request->working_expepierances as $key => $value) {
                if ($value['institute_name'] != null && $value['job_title'] != null && $value['start_date'] != null && $value['end_date'] != null) {
                    $data = array(
                        'tutor_id' => $tutor->id,
                        'institute_name' => $value['institute_name'],
                        'job_location' => $value['job_location'],
                        'job_type' => $value['job_type'],
                        'job_title' => $value['job_title'],
                        'start_date' => $value['start_date'] != null  ? date('Y-m-d',strtotime($value['start_date'])) : null,
                        'end_date' => $value['end_date'] != null  ? date('Y-m-d',strtotime($value['end_date'])) : null,
                    );
                    DB::table('tutor_exps')->insert($data);
                }
            }
        }


        $admin = DB::table('users')
                ->select('users.email')
                ->leftJoin('model_has_roles','users.id','=','model_has_roles.model_id')
                ->leftJoin('roles','roles.id','=','model_has_roles.role_id')
                ->where('roles.id',6)
                ->first();

        $users = Auth::user();


        if($users == ''){
            Mail::to($admin->email)->send(new AdminNotificationForTutorCreation($tutor));
            Auth::loginUsingId($user->id);
            return redirect()->route('home')->with('message','You Have Registered Successfully');
        }else{
            if ($users->roles->first()->name == 'tuition center') {
                return redirect()->route('centre-manager.index')->with('message', 'Tutor data saved successfully');
            }elseif($users->roles->first()->name == 'tutor'){
                return redirect()->route('home')->with('message','Profile Updated Successfully');
            }
        }

        if ($users != '') {
            $title = "Tutor";
            $msg = $request->first_name.' tutor created';

            Mail::to($request->email)->send(new TutorMail($title, $msg));
        }
        return redirect()->route('tutor.index')->with('message', 'Tutor data saved successfully');
    }

    public function show(Request $request,$id)
    {
        if($request->show){
            $show = $request->show;
        }else{
            $show = '';
        }
        $role = 'tutor';
        $tutor = Account::where('user_id',$id)->first();
        $edit_route =  route('update-tutor-account-link').'?id='.$tutor->id;
        $previous = route('tutor.index');
        $value = Account::where('user_id',$id)->first();
        $tutor_work_exp = DB::table('tutor_exps')->where('tutor_id',$tutor->id)->get();
        return view('tutors.show',compact('value','show','role','previous','edit_route','tutor_work_exp'));
    }

    public function edit(Request $request,$id)
    {
        $tutor = Account::find($id);
        $edit = 1;
        if($request->from_profile){
            $previous = route('tutor.show',$tutor->user_id);
            $from_profile = 1;
        }else{
            $previous = route('tutor.index');
            $from_profile = 0;
        }
        return view('tutors.edit', compact('tutor','edit','previous','from_profile'));
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'email' => 'required|email|unique:accounts,email,' . $id,
            'contact_number' => 'required',
        ]);

        $tutor = Account::find($id);
        $user = User::find($tutor->user_id);

        if ($logo = $request->file('profile_picture')) {
            $logo_name = $request->first_name . $request->file('profile_picture')->getClientOriginalName();
            $target_path = public_path('/profile_pictures/');

            if ($logo->move($target_path, $logo_name)) {
                $tutor->profile_picture = $logo_name;
            }
        }

        $tutor->first_name = $request->first_name;
        $tutor->last_name = $request->last_name;
        $tutor->email = $request->email;
        $tutor->contact_number = $request->contact_number;
        $tutor->remarks = $request->remarks;
        if ($request->password != "") {
            if ($request->password != $request->password_confirmation) {
                return redirect()->back()->withErrors(["Confirm Password didn't match"])->withInput();
            } else {
                User::where('id', $tutor->user_id)->update([
                    'name' => $request->first_name . " " . $request->last_name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password),
                ]);
                $tutor->password = Hash::make($request->password);
            }
        } else {
            $user = User::where('id', $tutor->user_id)->update([
                'name' => $request->first_name . " " . $request->last_name,
                'email' => $request->email,
            ]);
        }
        $tutor->save();

        $subjects = DB::table('tutor_subjects')->where('tutor_id', $tutor->id)->get();

        $tutor_educations = DB::table('tutor_educations')->where('tutor_id',$tutor->id)->get();
        return view('tutors.info_create', compact('tutor', 'subjects','tutor_educations'));

        // return redirect()->route('home')->with('message', 'Tutor updated successfully')->with('tab', 'tutor');
    }

    public function destroy($id)
    {
        $tutor = Account::find($id);
        User::find($tutor->user_id)->delete();
        $tutor->delete();
        $user = Auth::user();
        if ($user->roles->first()->name == 'tuition center') {
            return redirect()->route('centre-manager.index')->with('message', 'Tutor deleted successfully');
        }
        return redirect()->route('tutor.index')->with('message', 'Tutor deleted successfully');
    }

    public function storeInfoTutor(Request $request)
    {
        // dd($request->all());
        $tutor = Account::find($request->tutor_id);
        if ($logo = $request->file('attach_certificate')) {
            $logo_name = $request->file('attach_certificate')->getClientOriginalName();
            $target_path = public_path('/tutor_certificates/');

            if ($logo->move($target_path, $logo_name)) {
                $tutor->tutor_certificate = $logo_name;
            }
        }

        $tutor->breif_note = $request->breif_note;
        if ($request->subjects) {
            DB::table('tutor_subjects')->where('tutor_id', $tutor->id)->delete();
            foreach ($request->subjects as $sub) {
                $data = array(
                    'tutor_id' => $tutor->id,
                    'subject_id' => $sub,
                    'created_at' => date('Y-m-d'),
                );
                DB::table('tutor_subjects')->insert($data);
            }
        }

        if ($request->institute_name1) {
            DB::table('tutor_educations')->where('tutor_id', $tutor->id)->delete();
            $data = array(
                'tutor_id' => $tutor->id,
                'institute_name' => $request->institute_name1,
                'course_name' => $request->course_name1,
                'start_date' => $request->start_date1,
                'end_date' => $request->end_date1,
                'created_at' => date('Y-m-d'),
            );
            DB::table('tutor_educations')->insert($data);
        } else {
            DB::table('tutor_educations')->insert(['tutor_id' => $tutor->id]);
        }

        if ($request->institute_name2) {
            $data = array(
                'tutor_id' => $tutor->id,
                'institute_name' => $request->institute_name2,
                'course_name' => $request->course_name2,
                'start_date' => $request->start_date2,
                'end_date' => $request->end_date2,
                'created_at' => date('Y-m-d'),
            );
            DB::table('tutor_educations')->insert($data);
        } else {
            DB::table('tutor_educations')->insert(['tutor_id' => $tutor->id]);
        }

        $tutor->street_name = $request->street_name;
        $tutor->state = $request->state;
        $tutor->city = $request->city;
        $tutor->zip_code = $request->zip_code;
        $tutor->work_experience = $request->work_experience;
        $tutor->save();
        DB::table('tutor_exps')->where('tutor_id', $tutor->id)->delete();
            $data = array(
                'tutor_id' => $tutor->id,
                'institute_name' => $request->institute_name,
                'job_location' => $request->job_location,
                'job_type' => $request->job_type,
                'job_title' => $request->job_title,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date
            );
        DB::table('tutor_exps')->insert($data);
        $user = Auth::user();
        if ($user->roles->first()->name == 'tuition center') {
            return redirect()->route('centre-manager.index')->with('message', 'Tutor data saved successfully');
        }

        return redirect()->route('tutor.index')->with('message', 'Tutor data saved successfully');
    }

    public function addEducationDetail(Request $request, $tutor_id)
    {
        if ($request->institute_name) {
            $data = array(
                'tutor_id' => $tutor_id,
                'institute_name' => $request->institute_name,
                'course_name' => $request->course_name,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date,
                'created_at' => date('Y-m-d'),
            );
            DB::table('tutor_educations')->insert($data);
            return redirect()->back()->with('message', 'Education details saved successfully');
        }
        return redirect()->back()->withErrors(['msg' => "Please enter all the fields."]);
    }

    public function editEducationDetail(Request $request, $tutor_id, $edu_id)
    {
        if ($request->institute_name) {
            $data = array(
                'tutor_id' => $tutor_id,
                'institute_name' => $request->institute_name,
                'course_name' => $request->course_name,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date
            );
            DB::table('tutor_educations')->where('id', $edu_id)->update($data);
            return redirect()->back()->with('message', 'Education details saved successfully');
        }
        return redirect()->back()->withErrors(['msg' => "Please enter all the fields."]);
    }

    public function updateProfilePhoto(Request $request, $tutor_id)
    {
        $tutor = Account::find($tutor_id);

        if ($logo = $request->file('profile_picture')) {
            $logo_name = $tutor->first_name . $request->file('profile_picture')->getClientOriginalName();
            $target_path = public_path('/profile_pictures/');

            if ($logo->move($target_path, $logo_name)) {
                $tutor->profile_picture = $logo_name;
                $tutor->save();
                return redirect()->back()->with('message', 'Profile photo saved successfully.');
            }
            return redirect()->back()->withErrors(['msg' => "Failed to save image."]);
        }
        return redirect()->back()->withErrors(['msg' => "Please upload valid image."]);
    }

    public function editPersonalDetails(Request $request, $tutor_id)
    {
        $tutor = Account::find($tutor_id);
        $tutor->first_name = $request->first_name;
        $tutor->last_name = $request->last_name;
        $tutor->email = $request->email;
        $tutor->contact_number = $request->contact_number;
        $tutor->breif_note = $request->breif_note;
        $tutor->nationality = $request->nationality;
        $tutor->street_name = $request->street_name;
        $tutor->zip_code = $request->zip_code;
        $tutor->save();

        return redirect()->back()->with('message', 'Profile details saved successfully.');
    }

    public function addExpDetail(Request $request, $tutor_id)
    {
        if ($request->institute_name) {
            $data = array(
                'tutor_id' => $tutor_id,
                'institute_name' => $request->institute_name,
                'course_name' => $request->course_name,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date,
                'created_at' => date('Y-m-d'),
            );
            DB::table('tutor_exps')->insert($data);
            return redirect()->back()->with('message', 'Employment details saved successfully');
        }
        return redirect()->back()->withErrors(['msg' => "Please enter all the fields."]);
    }

    public function editExpDetail(Request $request, $tutor_id, $exp_id)
    {
        if ($request->institute_name) {
            $data = array(
                'tutor_id' => $tutor_id,
                'institute_name' => $request->institute_name,
                'course_name' => $request->course_name,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date
            );
            DB::table('tutor_exps')->where('id', $exp_id)->update($data);
            return redirect()->back()->with('message', 'Employment details saved successfully');
        }
        return redirect()->back()->withErrors(['msg' => "Please enter all the fields."]);
    }
}
