<?php

namespace App\Http\Controllers;

use App\Models\Account;
use App\Models\User;
use DataTables;
use DB;
use File;
use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('users.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $roles = Role::whereNotIn('name',['super_admin','parent','tuition center','student','tutor'])->get();
        $edit = 0;
        $role = '';
        $contact_number = 65;
        return view('users.create',compact('contact_number','roles','edit','role'));
    }

    public function Data()
    {
        $all_users = User::orderBy('updated_at','desc')->get();
        $admins = [];
        foreach($all_users as $user){
            $role = DB::table('model_has_roles')->where('model_id',$user->id)->first();
            if($role != ''){
                if($user->roles->first()->name != 'tuition center' && $user->roles->first()->name != 'tutor' && $user->roles->first()->name != 'student'  && $user->roles->first()->name != 'parent'){
                    array_push($admins, $user);
                }
            }

        }
        return DataTables::of($admins)
        ->editColumn('role', function ($admin) {
            $role = $admin->roles->first();
            if($role)
                return ucfirst(str_replace('_',' ',$role->name));
            else
                return '-';
        })
        ->editColumn('created_at', function ($admin) {
            return date('d-m-Y', strtotime($admin->created_at));
        })
        ->editColumn('contact_number', function ($admin) {
            $account = Account::where('user_id',$admin->id)->first();
            return $account->contact_number;
        })
        ->addColumn('updated_at', function ($admin) {
            return date('Y-m-d', strtotime($admin->updated_at));
        })
        ->editColumn('email', function ($admin) {
            return $admin->email;
        })
        ->editColumn('status', function ($admin) {
            $account = Account::where('user_id',$admin->id)->first();
            if($account->status == 'inactive'){
                return '<a class="btn btn-warning" onclick="return confirm(\'Are you sure want to Active ?\');" style="border:none;color:#ce7906;background:#ed921847;" href="'.route('account.changestatus',['id' => $admin->id,'value' => 1,'user'=>'Admin']).'">Inactive</a>';
            }else{
                return '<a class="btn btn-success" onclick="return confirm(\'Are you sure want to Inactive ?\');" style="border:none;color:#26ab38;background:#26ab3863;" href="'.route('account.changestatus',['id' => $admin->id,'value' => 0,'user'=>'Admin']).'">Active</a>';
            }
        })
        ->addColumn('actions', function ($admin) {
            return view('users.action', ['admin' => $admin]);
        })
        ->escapeColumns('ratings')
        ->rawColumns(['actions','status'])->make(true);
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $this->validate($request, [
            // 'profile_picture' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'gender' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email',
            'contact_number' => 'required',
            'password' => 'required|required_with:password_confirmation|same:password_confirmation',
            // 'password_confirmation' => 'min:6',
        ]);

        $user = User::create([
            'name' => $request->first_name." ".$request->last_name,
            'email' => $request->email,
            'password' => Hash::make($request->password)
        ]);
        // $user->assignRole($request->role_id);
        $user->assignRole(Role::find($request->role)->name);

        $updated_logo_name = "";
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

            $updated_logo_name = $imageName;
        }
        if($request->status){
            $status = $request->status;
        }else{
            $status = 'active';
        }
        $superadmin_details = array(
            'user_id' => $user->id,
            'profile_picture' => $updated_logo_name,
            'first_name' => $request->first_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'street_name' => $request->street_name,
            'state' => $request->state,
            'city' => $request->city,
            'zip_code' => $request->zip_code,
            'email' => $request->email,
            'contact_number' => $request->countryCode.$request->contact_number,
            'remarks' => $request->remarks,
            'status' => $status
        );
        DB::table('accounts')->insert($superadmin_details);
        return redirect()->route('users.index')->with('message', 'User created successfully');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Request $request,$id)
    {
        if($request->show){
            $show = $request->show;
          }else{
            $show = '';
          }
        $value = Account::where('user_id',$id)->first();
        $user = User::find($id);
        $role = $user->roles->first()->name;
        $previous = route('users.index');
        $edit_route = route('users.edit', $id);
        return view('users.show',compact('value','role','show','previous','edit_route'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request,$id)
    {
        $admin = User::find($id);
        $admin_details = DB::table('accounts')->where('user_id',$id)->first();
        $roles = Role::whereNotIn('name',['super_admin','parent','tuition center','student','tutor'])->get();
        $edit = 1;
        if($request->from_profile){
            $previous = route('users.show',$id);
            $from_profile = 1;
        }else{
            $previous = route('users.index');
            $from_profile = 0;
        }
        $role = $admin->roles->first()->name;
        $contact_number = substr($admin_details->contact_number, 0, -10) == '' ? 65 : substr($admin_details->contact_number, 0, -10);
        return view('users.edit', compact('roles', 'admin','admin_details','edit','previous','from_profile','role','contact_number'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request,$id)
    {
        // dd($request,$id);
        $sup = DB::table('accounts')->where('user_id',$id)->first();
        $sup_id = $sup ? $sup->id : '';
        $this->validate($request, [
            'first_name' => 'required|min:3|max:50',
            'last_name' => 'required',
            'gender' => 'required',
            'street_name' => 'required',
            'state' => 'required',
            'city' => 'required',
            'zip_code' => 'required',
            'email' => 'required|email|unique:users,email,'.$id,
            'contact_number' => 'required',
        ]);

        $user = User::find($id);
        $user->roles()->sync($request->role);
        // $user->syncRoles($request->role_id);
        if($request->status){
            $status = $request->status;
        }else{
            $status = 'active';
        }
        $updated_logo_name = "";
        if ($request->profile_picture != '') {
            $image = $request->profile_picture_url;  // your base64 encoded
            $image = str_replace('data:image/png;base64,', '', $image);
            $image = str_replace(' ', '+', $image);
            $imageName = $request->profile_picture;

            $path = public_path() . '/profile_pictures/';
            File::exists($path) or File::makeDirectory($path, 0777, true);
            File::put(public_path() . '/profile_pictures/' . $imageName, base64_decode($image));

            $updated_logo_name = $imageName;
        }

        if($request->password != ""){
            if($request->password != $request->password_confirmation){
                return redirect()->back()->withErrors(["Confirm Password didn't match"])->withInput();
            } else {
                $user = User::where('id', $id)->update([
                    'name' => $request->first_name." ".$request->last_name,
                    'email' => $request->email,
                    'password' => Hash::make($request->password)
                ]);
            }
        } else {
            $user = User::where('id', $id)->update([
                'name' => $request->first_name." ".$request->last_name,
                    'email' => $request->email,
            ]);
        }
        $find_admin = DB::table('accounts')->where('user_id',$id)->first();
        if($find_admin != ''){
        if($updated_logo_name){
            $superadmin_details = array(
                'profile_picture' => $updated_logo_name,
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'gender' => $request->gender,
                'street_name' => $request->street_name,
                'state' => $request->state,
                'city' => $request->city,
                'zip_code' => $request->zip_code,
                'email' => $request->email,
                'contact_number' => $request->countryCode.$request->contact_number,
                'remarks' => $request->remarks,
                'status' => $status
            );
        } else {
            $superadmin_details = array(
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'gender' => $request->gender,
                'street_name' => $request->street_name,
                'state' => $request->state,
                'city' => $request->city,
                'zip_code' => $request->zip_code,
                'email' => $request->email,
                'contact_number' => $request->countryCode.$request->contact_number,
                'remarks' => $request->remarks,
                'status' => $status
            );
        }
        DB::table('accounts')->where('user_id',$id)->update($superadmin_details);

    }else{
        $superadmin_details = array(
            'user_id' => $id,
            'profile_picture' => $updated_logo_name,
            'first_name' => $request->first_name,
            'last_name' => $request->last_name,
            'gender' => $request->gender,
            'street_name' => $request->street_name,
            'state' => $request->state,
            'city' => $request->city,
            'zip_code' => $request->zip_code,
            'email' => $request->email,
            'contact_number' => $request->countryCode.$request->contact_number,
            'remarks' => $request->remarks,
            'status' => $status
        );
        DB::table('accounts')->insert($superadmin_details);
    }
    if($request->from_profile == 1){
        return redirect()->route('users.show',$id)->with('message', 'User updated successfully');
    }else{
        return redirect()->route('users.index')->with('message', 'User updated successfully');
    }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request, $id)
    {
        User::find($id)->delete();
        DB::table('accounts')->where('user_id',$id)->delete();

        return redirect()->route('users.index')->with('message', 'User deleted successfully');
    }
}
