@extends('layouts.guest')
@section('content')
    <section class="parent-sign-up-form">
        <div class="container">
            <div class="sign-up-form-wrapper">
                <div class="form-head">
                    <h3>Welcome,</h3>
                    <h4>Enter your details below to sign up</h4>
                </div>
                @if ($errors->any())
                    <div class="alert alert-danger">
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </div>
                @endif
                @if(session()->has('message'))
                    <div class="alert alert-success">
                        {{ session()->get('message') }}
                    </div>
                @endif
                <div class="sign-up-wrap">
                    <div class="sign-up-form">
                        <form action="" method="POST" enctype="multipart/form-data" id="regForm">
                            @csrf
                            <div class="row">
                                <div class="col-xl-12">
                                    <div class="form-group mt-2 mb-2">
                                        <label>Name</label>
                                        <input type="text" value="{{ session()->get('name') ? session()->get('name') : old('first_name') }}" name="first_name"
                                            id="first_name" class="form-control" placeholder="Enter your full name"
                                            required>
                                    </div>
                                </div>
                                <div class="col-xl-12">
                                    <div class="form-group mt-2 mb-2">
                                        <label>Email Id</label>
                                        <input name="email" pattern="^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,4}$"
                                            value="{{ old('email') }}" type="email" id="email" class="form-control"
                                            placeholder="Enter your email id" required>
                                    </div>
                                </div>
                                <div class="col-xl-12">
                                    <div class="form-group mt-2 mb-2">
                                        <label>Create Password</label>
                                        <input name="password" type="password" id="password" autocomplete="new-password"
                                            class="form-control" placeholder="Create the password" required>
                                    </div>
                                </div>
                                <div class="col-xl-12">
                                    <div class="form-group mt-2 mb-2">
                                        <label>Confirm Password</label>
                                        <input name="password_confirmation" type="password" id="password_confirmation1" class="form-control"
                                            placeholder="Confirm the password" required>
                                    </div>
                                </div>
                                <input type="hidden" name="class" value="{{ $class_id }}">
                                <div class="btn-wrap">
                                    <div class="col-xl-12">
                                        <div class="form-group mt-2 mb-2">
                                            <!-- Button trigger modal -->
                                            <button type="submit" id="sign_up" class="custom-btn common-transition">
                                                Sign Up
                                            </button>

                                            <!--<button type="submit" class="btn custom-btn common-transition">Sign
                                                    Up</button>-->
                                            {{-- Sign In.html --}}
                                            @if($class_id)
                                                <h5>Already have an account? <a href="{{ route('account.sign_in') }}?user=parent&class_id={{ $class_id }}">Sign In</a> </h5>
                                            @else
                                                <h5>Already have an account? <a href="{{ route('account.sign_in') }}?user=parent">Sign In</a> </h5>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
        <!-- Modal -->

    </section>
    @include('layouts.footer')
@endsection
<style type="text/css">
    #email-error {
        color: red;
    }

    #email_child-error {
        color: red;
    }
</style>
@push('scripts')
    <script src="https://code.jquery.com/jquery-1.11.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/jquery.validation/1.16.0/jquery.validate.min.js"></script>
    <script src="https://cdn.jsdelivr.net/jquery.validation/1.16.0/additional-methods.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#sign_up').click(function(){
              $('#first_name_parent').val($('#first_name').val());
              $('#email_parent').val($('#email').val());
              $('#password_confirmation_parent').val($('#password_confirmation1').val());
              $('#password_parent').val($('#password').val());
            });
            $.validator.addMethod(
                "regex",
                function(value, element, regexp) {
                    var re = new RegExp(regexp);
                    return this.optional(element) || re.test(value);
                },
                "Please check your input."
            );
            $.ajaxSetup({
  headers: {
    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
  }
});
            $('form[id="regForm"]').validate({
                rules: {
                    first_name: {
                        required: true,
                        minlength: 3,
                    },

                    email: {
                        required: true,
                        email: true,
                        remote: {
                            url: "{{ url('/validate') }}",
                            data: {
                                from: 'parent',
                            },
                            type: 'get',
                        }
                    },
                    password: {
                        required: true,
                    },
                    password_confirmation: {
                        required: true,
                        equalTo: "#password"
                    },
                },
                messages: {
                    first_name: {
                        required: "<span style='color:red;'>This field is required.</span>",
                        minlength: "<span style='color:red;'>Enter Name at least 3 character.</span>",
                    },
                    email: {
                        required: "<span style='color:red;'>This field is required.</span>",
                        remote: "<span style='color:red;'>Email Already Exist.</span>",
                    },
                    password: "<span style='color:red;'>This field is required.</span>",
                    password_confirmation: {
                        required: "<span style='color:red;'>This field is required.</span>",
                        equalTo: "<span style='color:red;'>Confirm Password Not Matched.</span>",
                    }
                },
                submitHandler: function(form) {
                    $('#regForm').attr('action', '{{ route('store-account') }}');
                    form.submit();
                }
            });
        });
    </script>
@endpush
